# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class MultiClusterApp(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for multi cluster app object (map)
    """
    answers: pulumi.Output[list]
    """
    The multi cluster app answers (list)

      * `cluster_id` (`str`) - Cluster ID for answer (string)
      * `project_id` (`str`) - Project ID for target (string)
      * `values` (`dict`) - Key/values for answer (map)
    """
    catalog_name: pulumi.Output[str]
    """
    The multi cluster app catalog name (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for multi cluster app object (map)
    """
    members: pulumi.Output[list]
    """
    The multi cluster app answers (list)

      * `accessType` (`str`) - Member access type. Valid values: `["member" | "owner" | "read-only"]` (string)
      * `group_principal_id` (`str`) - Member group principal id (string)
      * `user_principal_id` (`str`) - Member user principal id (string)
    """
    name: pulumi.Output[str]
    """
    The multi cluster app name (string)
    """
    revision_history_limit: pulumi.Output[float]
    """
    The multi cluster app revision history limit. Default `10` (int)
    """
    revision_id: pulumi.Output[str]
    """
    Current revision id for the multi cluster app (string)
    """
    roles: pulumi.Output[list]
    """
    The multi cluster app roles (list)
    """
    targets: pulumi.Output[list]
    """
    The multi cluster app target projects (list)

      * `appId` (`str`) - App ID for target (string)
      * `healthState` (`str`) - App health state for target (string)
      * `project_id` (`str`) - Project ID for target (string)
      * `state` (`str`) - App state for target (string)
    """
    template_name: pulumi.Output[str]
    """
    The multi cluster app template name (string)
    """
    template_version: pulumi.Output[str]
    """
    The multi cluster app template version. Default: `latest` (string)
    """
    template_version_id: pulumi.Output[str]
    """
    (Computed) The multi cluster app template version ID (string)
    """
    upgrade_strategy: pulumi.Output[dict]
    """
    The multi cluster app upgrade strategy (list MaxItems:1)

      * `rollingUpdate` (`dict`) - Upgrade strategy rolling update (list MaxItems:1)
        * `batchSize` (`float`) - Rolling update batch size. Default `1` (int)
        * `interval` (`float`) - Rolling update interval. Default `1` (int)
    """
    wait: pulumi.Output[bool]
    """
    Wait until the multi cluster app is active. Default `true` (bool)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, answers=None, catalog_name=None, labels=None, members=None, name=None, revision_history_limit=None, revision_id=None, roles=None, targets=None, template_name=None, template_version=None, upgrade_strategy=None, wait=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a MultiClusterApp resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for multi cluster app object (map)
        :param pulumi.Input[list] answers: The multi cluster app answers (list)
        :param pulumi.Input[str] catalog_name: The multi cluster app catalog name (string)
        :param pulumi.Input[dict] labels: Labels for multi cluster app object (map)
        :param pulumi.Input[list] members: The multi cluster app answers (list)
        :param pulumi.Input[str] name: The multi cluster app name (string)
        :param pulumi.Input[float] revision_history_limit: The multi cluster app revision history limit. Default `10` (int)
        :param pulumi.Input[str] revision_id: Current revision id for the multi cluster app (string)
        :param pulumi.Input[list] roles: The multi cluster app roles (list)
        :param pulumi.Input[list] targets: The multi cluster app target projects (list)
        :param pulumi.Input[str] template_name: The multi cluster app template name (string)
        :param pulumi.Input[str] template_version: The multi cluster app template version. Default: `latest` (string)
        :param pulumi.Input[dict] upgrade_strategy: The multi cluster app upgrade strategy (list MaxItems:1)
        :param pulumi.Input[bool] wait: Wait until the multi cluster app is active. Default `true` (bool)

        The **answers** object supports the following:

          * `cluster_id` (`pulumi.Input[str]`) - Cluster ID for answer (string)
          * `project_id` (`pulumi.Input[str]`) - Project ID for target (string)
          * `values` (`pulumi.Input[dict]`) - Key/values for answer (map)

        The **members** object supports the following:

          * `accessType` (`pulumi.Input[str]`) - Member access type. Valid values: `["member" | "owner" | "read-only"]` (string)
          * `group_principal_id` (`pulumi.Input[str]`) - Member group principal id (string)
          * `user_principal_id` (`pulumi.Input[str]`) - Member user principal id (string)

        The **targets** object supports the following:

          * `appId` (`pulumi.Input[str]`) - App ID for target (string)
          * `healthState` (`pulumi.Input[str]`) - App health state for target (string)
          * `project_id` (`pulumi.Input[str]`) - Project ID for target (string)
          * `state` (`pulumi.Input[str]`) - App state for target (string)

        The **upgrade_strategy** object supports the following:

          * `rollingUpdate` (`pulumi.Input[dict]`) - Upgrade strategy rolling update (list MaxItems:1)
            * `batchSize` (`pulumi.Input[float]`) - Rolling update batch size. Default `1` (int)
            * `interval` (`pulumi.Input[float]`) - Rolling update interval. Default `1` (int)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            __props__['answers'] = answers
            if catalog_name is None:
                raise TypeError("Missing required property 'catalog_name'")
            __props__['catalog_name'] = catalog_name
            __props__['labels'] = labels
            __props__['members'] = members
            __props__['name'] = name
            __props__['revision_history_limit'] = revision_history_limit
            __props__['revision_id'] = revision_id
            if roles is None:
                raise TypeError("Missing required property 'roles'")
            __props__['roles'] = roles
            if targets is None:
                raise TypeError("Missing required property 'targets'")
            __props__['targets'] = targets
            if template_name is None:
                raise TypeError("Missing required property 'template_name'")
            __props__['template_name'] = template_name
            __props__['template_version'] = template_version
            __props__['upgrade_strategy'] = upgrade_strategy
            __props__['wait'] = wait
            __props__['template_version_id'] = None
        super(MultiClusterApp, __self__).__init__(
            'rancher2:index/multiClusterApp:MultiClusterApp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, answers=None, catalog_name=None, labels=None, members=None, name=None, revision_history_limit=None, revision_id=None, roles=None, targets=None, template_name=None, template_version=None, template_version_id=None, upgrade_strategy=None, wait=None):
        """
        Get an existing MultiClusterApp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for multi cluster app object (map)
        :param pulumi.Input[list] answers: The multi cluster app answers (list)
        :param pulumi.Input[str] catalog_name: The multi cluster app catalog name (string)
        :param pulumi.Input[dict] labels: Labels for multi cluster app object (map)
        :param pulumi.Input[list] members: The multi cluster app answers (list)
        :param pulumi.Input[str] name: The multi cluster app name (string)
        :param pulumi.Input[float] revision_history_limit: The multi cluster app revision history limit. Default `10` (int)
        :param pulumi.Input[str] revision_id: Current revision id for the multi cluster app (string)
        :param pulumi.Input[list] roles: The multi cluster app roles (list)
        :param pulumi.Input[list] targets: The multi cluster app target projects (list)
        :param pulumi.Input[str] template_name: The multi cluster app template name (string)
        :param pulumi.Input[str] template_version: The multi cluster app template version. Default: `latest` (string)
        :param pulumi.Input[str] template_version_id: (Computed) The multi cluster app template version ID (string)
        :param pulumi.Input[dict] upgrade_strategy: The multi cluster app upgrade strategy (list MaxItems:1)
        :param pulumi.Input[bool] wait: Wait until the multi cluster app is active. Default `true` (bool)

        The **answers** object supports the following:

          * `cluster_id` (`pulumi.Input[str]`) - Cluster ID for answer (string)
          * `project_id` (`pulumi.Input[str]`) - Project ID for target (string)
          * `values` (`pulumi.Input[dict]`) - Key/values for answer (map)

        The **members** object supports the following:

          * `accessType` (`pulumi.Input[str]`) - Member access type. Valid values: `["member" | "owner" | "read-only"]` (string)
          * `group_principal_id` (`pulumi.Input[str]`) - Member group principal id (string)
          * `user_principal_id` (`pulumi.Input[str]`) - Member user principal id (string)

        The **targets** object supports the following:

          * `appId` (`pulumi.Input[str]`) - App ID for target (string)
          * `healthState` (`pulumi.Input[str]`) - App health state for target (string)
          * `project_id` (`pulumi.Input[str]`) - Project ID for target (string)
          * `state` (`pulumi.Input[str]`) - App state for target (string)

        The **upgrade_strategy** object supports the following:

          * `rollingUpdate` (`pulumi.Input[dict]`) - Upgrade strategy rolling update (list MaxItems:1)
            * `batchSize` (`pulumi.Input[float]`) - Rolling update batch size. Default `1` (int)
            * `interval` (`pulumi.Input[float]`) - Rolling update interval. Default `1` (int)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["answers"] = answers
        __props__["catalog_name"] = catalog_name
        __props__["labels"] = labels
        __props__["members"] = members
        __props__["name"] = name
        __props__["revision_history_limit"] = revision_history_limit
        __props__["revision_id"] = revision_id
        __props__["roles"] = roles
        __props__["targets"] = targets
        __props__["template_name"] = template_name
        __props__["template_version"] = template_version
        __props__["template_version_id"] = template_version_id
        __props__["upgrade_strategy"] = upgrade_strategy
        __props__["wait"] = wait
        return MultiClusterApp(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetEtcdBackupResult:
    """
    A collection of values returned by getEtcdBackup.
    """
    def __init__(__self__, annotations=None, backup_config=None, cluster_id=None, filename=None, id=None, labels=None, manual=None, name=None, namespace_id=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for Etcd Backup object (map)
        """
        if backup_config and not isinstance(backup_config, dict):
            raise TypeError("Expected argument 'backup_config' to be a dict")
        __self__.backup_config = backup_config
        """
        (Computed) Backup config for etcd backup (list maxitems:1)
        """
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        __self__.cluster_id = cluster_id
        if filename and not isinstance(filename, str):
            raise TypeError("Expected argument 'filename' to be a str")
        __self__.filename = filename
        """
        (Computed) Filename of the Etcd Backup (string)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for Etcd Backup object (map)
        """
        if manual and not isinstance(manual, bool):
            raise TypeError("Expected argument 'manual' to be a bool")
        __self__.manual = manual
        """
        (Computed) Manual execution of the Etcd Backup. Default `false` (bool)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if namespace_id and not isinstance(namespace_id, str):
            raise TypeError("Expected argument 'namespace_id' to be a str")
        __self__.namespace_id = namespace_id
        """
        (Computed) Description for the Etcd Backup (string)
        """
class AwaitableGetEtcdBackupResult(GetEtcdBackupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEtcdBackupResult(
            annotations=self.annotations,
            backup_config=self.backup_config,
            cluster_id=self.cluster_id,
            filename=self.filename,
            id=self.id,
            labels=self.labels,
            manual=self.manual,
            name=self.name,
            namespace_id=self.namespace_id)

def get_etcd_backup(cluster_id=None,name=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 etcd backup.




    :param str cluster_id: Cluster ID to config Etcd Backup (string)
    :param str name: The name of the Etcd Backup (string)
    """
    __args__ = dict()


    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getEtcdBackup:getEtcdBackup', __args__, opts=opts).value

    return AwaitableGetEtcdBackupResult(
        annotations=__ret__.get('annotations'),
        backup_config=__ret__.get('backupConfig'),
        cluster_id=__ret__.get('clusterId'),
        filename=__ret__.get('filename'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        manual=__ret__.get('manual'),
        name=__ret__.get('name'),
        namespace_id=__ret__.get('namespaceId'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class ClusterTemplate(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for the cluster template revision (map)
    """
    default_revision_id: pulumi.Output[str]
    """
    (Computed) Default cluster template revision ID (string)
    """
    description: pulumi.Output[str]
    """
    Cluster template description
    """
    labels: pulumi.Output[dict]
    """
    Labels for the cluster template revision (map)
    """
    members: pulumi.Output[list]
    """
    Cluster template members (list)

      * `accessType` (`str`) - Member access type. Valid values: `["read-only" | "owner"]` (string)
      * `group_principal_id` (`str`) - Member group principal id (string)
      * `user_principal_id` (`str`) - Member user principal id (string)
    """
    name: pulumi.Output[str]
    """
    The cluster template revision name (string)
    """
    template_revisions: pulumi.Output[list]
    """
    Cluster template revisions (list)

      * `annotations` (`dict`) - Annotations for the cluster template revision (map)
      * `clusterConfig` (`dict`) - Cluster configuration (list maxitem: 1)
        * `cluster_auth_endpoint` (`dict`) - Local cluster auth endpoint (list maxitems: 1)
          * `ca_certs` (`str`)
          * `enabled` (`bool`) - Enable cluster template revision. Default `true` (bool)
          * `fqdn` (`str`)

        * `defaultClusterRoleForProjectMembers` (`str`) - Default cluster role for project members (string)
        * `default_pod_security_policy_template_id` (`str`) - Default pod security policy template ID (string)
        * `desired_agent_image` (`str`) - Desired agent image (string)
        * `desired_auth_image` (`str`) - Desired auth image (string)
        * `docker_root_dir` (`str`) - Desired auth image (string)
        * `enable_cluster_alerting` (`bool`) - Enable built-in cluster alerting. Default: `false` (bool)
        * `enable_cluster_monitoring` (`bool`) - Enable built-in cluster monitoring. Default: `false` (bool)
        * `enable_network_policy` (`bool`) - Enable project network isolation. Default: `false` (bool)
        * `rke_config` (`dict`) - Rancher Kubernetes Engine Config (list maxitems: 1)
          * `addonJobTimeout` (`float`)
          * `addons` (`str`)
          * `addonsIncludes` (`list`)
          * `authentication` (`dict`)
            * `sans` (`list`)
            * `strategy` (`str`)

          * `authorization` (`dict`)
            * `mode` (`str`)
            * `options` (`dict`)

          * `bastionHost` (`dict`)
            * `address` (`str`)
            * `port` (`str`)
            * `sshAgentAuth` (`bool`)
            * `sshKey` (`str`)
            * `sshKeyPath` (`str`)
            * `user` (`str`)

          * `cloudProvider` (`dict`)
            * `awsCloudProvider` (`dict`)
              * `global` (`dict`)
                * `disableSecurityGroupIngress` (`bool`)
                * `disableStrictZoneCheck` (`bool`)
                * `elbSecurityGroup` (`str`)
                * `kubernetesClusterId` (`str`)
                * `kubernetesClusterTag` (`str`)
                * `roleArn` (`str`)
                * `routeTableId` (`str`)
                * `subnetId` (`str`)
                * `vpc` (`str`)
                * `zone` (`str`)

              * `serviceOverrides` (`list`)
                * `region` (`str`)
                * `service` (`str`)
                * `signingMethod` (`str`)
                * `signingName` (`str`)
                * `signingRegion` (`str`)
                * `url` (`str`)

            * `azureCloudProvider` (`dict`)
              * `aadClientCertPassword` (`str`)
              * `aadClientCertPath` (`str`)
              * `aadClientId` (`str`)
              * `aadClientSecret` (`str`)
              * `cloud` (`str`)
              * `cloudProviderBackoff` (`bool`)
              * `cloudProviderBackoffDuration` (`float`)
              * `cloudProviderBackoffExponent` (`float`)
              * `cloudProviderBackoffJitter` (`float`)
              * `cloudProviderBackoffRetries` (`float`)
              * `cloudProviderRateLimit` (`bool`)
              * `cloudProviderRateLimitBucket` (`float`)
              * `cloudProviderRateLimitQps` (`float`)
              * `location` (`str`)
              * `maximumLoadBalancerRuleCount` (`float`)
              * `primaryAvailabilitySetName` (`str`)
              * `primaryScaleSetName` (`str`)
              * `resourceGroup` (`str`)
              * `routeTableName` (`str`)
              * `securityGroupName` (`str`)
              * `subnetName` (`str`)
              * `subscriptionId` (`str`)
              * `tenant_id` (`str`)
              * `useInstanceMetadata` (`bool`)
              * `useManagedIdentityExtension` (`bool`)
              * `vmType` (`str`)
              * `vnetName` (`str`)
              * `vnetResourceGroup` (`str`)

            * `customCloudProvider` (`str`)
            * `name` (`str`) - The cluster template revision name (string)
            * `openstackCloudProvider` (`dict`)
              * `blockStorage` (`dict`)
                * `bsVersion` (`str`)
                * `ignoreVolumeAz` (`bool`)
                * `trustDevicePath` (`bool`)

              * `global` (`dict`)
                * `authUrl` (`str`)
                * `caFile` (`str`)
                * `domainId` (`str`)
                * `domainName` (`str`)
                * `password` (`str`)
                * `region` (`str`)
                * `tenant_id` (`str`)
                * `tenantName` (`str`)
                * `trustId` (`str`)
                * `username` (`str`)

              * `loadBalancer` (`dict`)
                * `createMonitor` (`bool`)
                * `floatingNetworkId` (`str`)
                * `lbMethod` (`str`)
                * `lbProvider` (`str`)
                * `lbVersion` (`str`)
                * `manageSecurityGroups` (`bool`)
                * `monitorDelay` (`str`)
                * `monitorMaxRetries` (`float`)
                * `monitorTimeout` (`str`)
                * `subnetId` (`str`)
                * `useOctavia` (`bool`)

              * `metadata` (`dict`)
                * `requestTimeout` (`float`)
                * `searchOrder` (`str`)

              * `route` (`dict`)
                * `routerId` (`str`)

            * `vsphereCloudProvider` (`dict`)
              * `disk` (`dict`)
                * `scsiControllerType` (`str`)

              * `global` (`dict`)
                * `datacenters` (`str`)
                * `insecureFlag` (`bool`)
                * `password` (`str`)
                * `port` (`str`)
                * `soapRoundtripCount` (`float`)
                * `user` (`str`)

              * `network` (`dict`)
                * `publicNetwork` (`str`)

              * `virtualCenters` (`list`)
                * `datacenters` (`str`)
                * `name` (`str`) - The cluster template revision name (string)
                * `password` (`str`)
                * `port` (`str`)
                * `soapRoundtripCount` (`float`)
                * `user` (`str`)

              * `workspace` (`dict`)
                * `datacenter` (`str`)
                * `defaultDatastore` (`str`)
                * `folder` (`str`)
                * `resourcepoolPath` (`str`)
                * `server` (`str`)

          * `dns` (`dict`)
            * `nodeSelector` (`dict`)
            * `provider` (`str`)
            * `reverseCidrs` (`list`)
            * `upstreamNameservers` (`list`)

          * `ignoreDockerVersion` (`bool`)
          * `ingress` (`dict`)
            * `dnsPolicy` (`str`)
            * `extraArgs` (`dict`)
            * `nodeSelector` (`dict`)
            * `options` (`dict`)
            * `provider` (`str`)

          * `kubernetesVersion` (`str`)
          * `monitoring` (`dict`)
            * `options` (`dict`)
            * `provider` (`str`)

          * `network` (`dict`)
            * `calicoNetworkProvider` (`dict`)
              * `cloudProvider` (`str`)

            * `canalNetworkProvider` (`dict`)
              * `iface` (`str`)

            * `flannelNetworkProvider` (`dict`)
              * `iface` (`str`)

            * `mtu` (`float`)
            * `options` (`dict`)
            * `plugin` (`str`)
            * `weaveNetworkProvider` (`dict`)
              * `password` (`str`)

          * `nodes` (`list`)
            * `address` (`str`)
            * `dockerSocket` (`str`)
            * `hostnameOverride` (`str`)
            * `internalAddress` (`str`)
            * `labels` (`dict`) - Labels for the cluster template revision (map)
            * `nodeId` (`str`)
            * `port` (`str`)
            * `roles` (`list`)
            * `sshAgentAuth` (`bool`)
            * `sshKey` (`str`)
            * `sshKeyPath` (`str`)
            * `user` (`str`)

          * `prefixPath` (`str`)
          * `privateRegistries` (`list`)
            * `isDefault` (`bool`)
            * `password` (`str`)
            * `url` (`str`)
            * `user` (`str`)

          * `services` (`dict`)
            * `etcd` (`dict`)
              * `backup_config` (`dict`)
                * `enabled` (`bool`) - Enable cluster template revision. Default `true` (bool)
                * `intervalHours` (`float`)
                * `retention` (`float`)
                * `s3BackupConfig` (`dict`)
                  * `access_key` (`str`)
                  * `bucketName` (`str`)
                  * `customCa` (`str`)
                  * `endpoint` (`str`)
                  * `folder` (`str`)
                  * `region` (`str`)
                  * `secret_key` (`str`)

                * `safeTimestamp` (`bool`)

              * `caCert` (`str`)
              * `cert` (`str`)
              * `creation` (`str`)
              * `externalUrls` (`list`)
              * `extraArgs` (`dict`)
              * `extraBinds` (`list`)
              * `extraEnvs` (`list`)
              * `gid` (`float`)
              * `image` (`str`)
              * `key` (`str`)
              * `path` (`str`)
              * `retention` (`str`)
              * `snapshot` (`bool`)
              * `uid` (`float`)

            * `kubeApi` (`dict`)
              * `admissionConfiguration` (`dict`)
              * `alwaysPullImages` (`bool`)
              * `auditLog` (`dict`)
                * `configuration` (`dict`)
                  * `format` (`str`)
                  * `maxAge` (`float`)
                  * `maxBackup` (`float`)
                  * `maxSize` (`float`)
                  * `path` (`str`)
                  * `policy` (`str`)

                * `enabled` (`bool`) - Enable cluster template revision. Default `true` (bool)

              * `eventRateLimit` (`dict`)
                * `configuration` (`dict`)
                * `enabled` (`bool`) - Enable cluster template revision. Default `true` (bool)

              * `extraArgs` (`dict`)
              * `extraBinds` (`list`)
              * `extraEnvs` (`list`)
              * `image` (`str`)
              * `podSecurityPolicy` (`bool`)
              * `secretsEncryptionConfig` (`dict`)
                * `customConfig` (`dict`)
                * `enabled` (`bool`) - Enable cluster template revision. Default `true` (bool)

              * `serviceClusterIpRange` (`str`)
              * `serviceNodePortRange` (`str`)

            * `kubeController` (`dict`)
              * `clusterCidr` (`str`)
              * `extraArgs` (`dict`)
              * `extraBinds` (`list`)
              * `extraEnvs` (`list`)
              * `image` (`str`)
              * `serviceClusterIpRange` (`str`)

            * `kubelet` (`dict`)
              * `clusterDnsServer` (`str`)
              * `clusterDomain` (`str`)
              * `extraArgs` (`dict`)
              * `extraBinds` (`list`)
              * `extraEnvs` (`list`)
              * `failSwapOn` (`bool`)
              * `generateServingCertificate` (`bool`)
              * `image` (`str`)
              * `infraContainerImage` (`str`)

            * `kubeproxy` (`dict`)
              * `extraArgs` (`dict`)
              * `extraBinds` (`list`)
              * `extraEnvs` (`list`)
              * `image` (`str`)

            * `scheduler` (`dict`)
              * `extraArgs` (`dict`)
              * `extraBinds` (`list`)
              * `extraEnvs` (`list`)
              * `image` (`str`)

          * `sshAgentAuth` (`bool`)
          * `sshCertPath` (`str`)
          * `sshKeyPath` (`str`)
          * `upgrade_strategy` (`dict`)
            * `drain` (`bool`)
            * `drainInput` (`dict`)
              * `deleteLocalData` (`bool`)
              * `force` (`bool`)
              * `gracePeriod` (`float`)
              * `ignoreDaemonSets` (`bool`)
              * `timeout` (`float`)

            * `maxUnavailableControlplane` (`str`)
            * `maxUnavailableWorker` (`str`)

        * `scheduled_cluster_scan` (`dict`) - Cluster scheduled cis scan. For Rancher v2.4.0 or above (List MaxItem:1)
          * `enabled` (`bool`) - Enable cluster template revision. Default `true` (bool)
          * `scanConfig` (`dict`)
            * `cisScanConfig` (`dict`)
              * `debugMaster` (`bool`)
              * `debugWorker` (`bool`)
              * `overrideBenchmarkVersion` (`str`)
              * `overrideSkips` (`list`)
              * `profile` (`str`)

          * `scheduleConfig` (`dict`)
            * `cronSchedule` (`str`)
            * `retention` (`float`)

        * `windows_prefered_cluster` (`bool`) - Windows prefered cluster. Default: `false` (bool)

      * `cluster_template_id` (`str`) - Cluster template ID (string)
      * `default` (`bool`) - Default variable value (string)
      * `enabled` (`bool`) - Enable cluster template revision. Default `true` (bool)
      * `id` (`str`) - The cluster template revision ID (string)
      * `labels` (`dict`) - Labels for the cluster template revision (map)
      * `name` (`str`) - The cluster template revision name (string)
      * `questions` (`list`) - Cluster template questions (list)
        * `default` (`str`) - Default variable value (string)
        * `required` (`bool`) - Required variable. Default `false` (bool)
        * `type` (`str`) - Variable type. `boolean`, `int` and `string` are allowed. Default `string` (string)
        * `variable` (`str`) - Variable name (string)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, description=None, labels=None, members=None, name=None, template_revisions=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Cluster Template resource. This can be used to create Cluster Templates for Rancher v2 RKE clusters and retrieve their information. 

        Cluster Templates are available from Rancher v2.3.x and above.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for the cluster template revision (map)
        :param pulumi.Input[str] description: Cluster template description
        :param pulumi.Input[dict] labels: Labels for the cluster template revision (map)
        :param pulumi.Input[list] members: Cluster template members (list)
        :param pulumi.Input[str] name: The cluster template revision name (string)
        :param pulumi.Input[list] template_revisions: Cluster template revisions (list)

        The **members** object supports the following:

          * `accessType` (`pulumi.Input[str]`) - Member access type. Valid values: `["read-only" | "owner"]` (string)
          * `group_principal_id` (`pulumi.Input[str]`) - Member group principal id (string)
          * `user_principal_id` (`pulumi.Input[str]`) - Member user principal id (string)

        The **template_revisions** object supports the following:

          * `annotations` (`pulumi.Input[dict]`) - Annotations for the cluster template revision (map)
          * `clusterConfig` (`pulumi.Input[dict]`) - Cluster configuration (list maxitem: 1)
            * `cluster_auth_endpoint` (`pulumi.Input[dict]`) - Local cluster auth endpoint (list maxitems: 1)
              * `ca_certs` (`pulumi.Input[str]`)
              * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)
              * `fqdn` (`pulumi.Input[str]`)

            * `defaultClusterRoleForProjectMembers` (`pulumi.Input[str]`) - Default cluster role for project members (string)
            * `default_pod_security_policy_template_id` (`pulumi.Input[str]`) - Default pod security policy template ID (string)
            * `desired_agent_image` (`pulumi.Input[str]`) - Desired agent image (string)
            * `desired_auth_image` (`pulumi.Input[str]`) - Desired auth image (string)
            * `docker_root_dir` (`pulumi.Input[str]`) - Desired auth image (string)
            * `enable_cluster_alerting` (`pulumi.Input[bool]`) - Enable built-in cluster alerting. Default: `false` (bool)
            * `enable_cluster_monitoring` (`pulumi.Input[bool]`) - Enable built-in cluster monitoring. Default: `false` (bool)
            * `enable_network_policy` (`pulumi.Input[bool]`) - Enable project network isolation. Default: `false` (bool)
            * `rke_config` (`pulumi.Input[dict]`) - Rancher Kubernetes Engine Config (list maxitems: 1)
              * `addonJobTimeout` (`pulumi.Input[float]`)
              * `addons` (`pulumi.Input[str]`)
              * `addonsIncludes` (`pulumi.Input[list]`)
              * `authentication` (`pulumi.Input[dict]`)
                * `sans` (`pulumi.Input[list]`)
                * `strategy` (`pulumi.Input[str]`)

              * `authorization` (`pulumi.Input[dict]`)
                * `mode` (`pulumi.Input[str]`)
                * `options` (`pulumi.Input[dict]`)

              * `bastionHost` (`pulumi.Input[dict]`)
                * `address` (`pulumi.Input[str]`)
                * `port` (`pulumi.Input[str]`)
                * `sshAgentAuth` (`pulumi.Input[bool]`)
                * `sshKey` (`pulumi.Input[str]`)
                * `sshKeyPath` (`pulumi.Input[str]`)
                * `user` (`pulumi.Input[str]`)

              * `cloudProvider` (`pulumi.Input[dict]`)
                * `awsCloudProvider` (`pulumi.Input[dict]`)
                  * `global` (`pulumi.Input[dict]`)
                    * `disableSecurityGroupIngress` (`pulumi.Input[bool]`)
                    * `disableStrictZoneCheck` (`pulumi.Input[bool]`)
                    * `elbSecurityGroup` (`pulumi.Input[str]`)
                    * `kubernetesClusterId` (`pulumi.Input[str]`)
                    * `kubernetesClusterTag` (`pulumi.Input[str]`)
                    * `roleArn` (`pulumi.Input[str]`)
                    * `routeTableId` (`pulumi.Input[str]`)
                    * `subnetId` (`pulumi.Input[str]`)
                    * `vpc` (`pulumi.Input[str]`)
                    * `zone` (`pulumi.Input[str]`)

                  * `serviceOverrides` (`pulumi.Input[list]`)
                    * `region` (`pulumi.Input[str]`)
                    * `service` (`pulumi.Input[str]`)
                    * `signingMethod` (`pulumi.Input[str]`)
                    * `signingName` (`pulumi.Input[str]`)
                    * `signingRegion` (`pulumi.Input[str]`)
                    * `url` (`pulumi.Input[str]`)

                * `azureCloudProvider` (`pulumi.Input[dict]`)
                  * `aadClientCertPassword` (`pulumi.Input[str]`)
                  * `aadClientCertPath` (`pulumi.Input[str]`)
                  * `aadClientId` (`pulumi.Input[str]`)
                  * `aadClientSecret` (`pulumi.Input[str]`)
                  * `cloud` (`pulumi.Input[str]`)
                  * `cloudProviderBackoff` (`pulumi.Input[bool]`)
                  * `cloudProviderBackoffDuration` (`pulumi.Input[float]`)
                  * `cloudProviderBackoffExponent` (`pulumi.Input[float]`)
                  * `cloudProviderBackoffJitter` (`pulumi.Input[float]`)
                  * `cloudProviderBackoffRetries` (`pulumi.Input[float]`)
                  * `cloudProviderRateLimit` (`pulumi.Input[bool]`)
                  * `cloudProviderRateLimitBucket` (`pulumi.Input[float]`)
                  * `cloudProviderRateLimitQps` (`pulumi.Input[float]`)
                  * `location` (`pulumi.Input[str]`)
                  * `maximumLoadBalancerRuleCount` (`pulumi.Input[float]`)
                  * `primaryAvailabilitySetName` (`pulumi.Input[str]`)
                  * `primaryScaleSetName` (`pulumi.Input[str]`)
                  * `resourceGroup` (`pulumi.Input[str]`)
                  * `routeTableName` (`pulumi.Input[str]`)
                  * `securityGroupName` (`pulumi.Input[str]`)
                  * `subnetName` (`pulumi.Input[str]`)
                  * `subscriptionId` (`pulumi.Input[str]`)
                  * `tenant_id` (`pulumi.Input[str]`)
                  * `useInstanceMetadata` (`pulumi.Input[bool]`)
                  * `useManagedIdentityExtension` (`pulumi.Input[bool]`)
                  * `vmType` (`pulumi.Input[str]`)
                  * `vnetName` (`pulumi.Input[str]`)
                  * `vnetResourceGroup` (`pulumi.Input[str]`)

                * `customCloudProvider` (`pulumi.Input[str]`)
                * `name` (`pulumi.Input[str]`) - The cluster template revision name (string)
                * `openstackCloudProvider` (`pulumi.Input[dict]`)
                  * `blockStorage` (`pulumi.Input[dict]`)
                    * `bsVersion` (`pulumi.Input[str]`)
                    * `ignoreVolumeAz` (`pulumi.Input[bool]`)
                    * `trustDevicePath` (`pulumi.Input[bool]`)

                  * `global` (`pulumi.Input[dict]`)
                    * `authUrl` (`pulumi.Input[str]`)
                    * `caFile` (`pulumi.Input[str]`)
                    * `domainId` (`pulumi.Input[str]`)
                    * `domainName` (`pulumi.Input[str]`)
                    * `password` (`pulumi.Input[str]`)
                    * `region` (`pulumi.Input[str]`)
                    * `tenant_id` (`pulumi.Input[str]`)
                    * `tenantName` (`pulumi.Input[str]`)
                    * `trustId` (`pulumi.Input[str]`)
                    * `username` (`pulumi.Input[str]`)

                  * `loadBalancer` (`pulumi.Input[dict]`)
                    * `createMonitor` (`pulumi.Input[bool]`)
                    * `floatingNetworkId` (`pulumi.Input[str]`)
                    * `lbMethod` (`pulumi.Input[str]`)
                    * `lbProvider` (`pulumi.Input[str]`)
                    * `lbVersion` (`pulumi.Input[str]`)
                    * `manageSecurityGroups` (`pulumi.Input[bool]`)
                    * `monitorDelay` (`pulumi.Input[str]`)
                    * `monitorMaxRetries` (`pulumi.Input[float]`)
                    * `monitorTimeout` (`pulumi.Input[str]`)
                    * `subnetId` (`pulumi.Input[str]`)
                    * `useOctavia` (`pulumi.Input[bool]`)

                  * `metadata` (`pulumi.Input[dict]`)
                    * `requestTimeout` (`pulumi.Input[float]`)
                    * `searchOrder` (`pulumi.Input[str]`)

                  * `route` (`pulumi.Input[dict]`)
                    * `routerId` (`pulumi.Input[str]`)

                * `vsphereCloudProvider` (`pulumi.Input[dict]`)
                  * `disk` (`pulumi.Input[dict]`)
                    * `scsiControllerType` (`pulumi.Input[str]`)

                  * `global` (`pulumi.Input[dict]`)
                    * `datacenters` (`pulumi.Input[str]`)
                    * `insecureFlag` (`pulumi.Input[bool]`)
                    * `password` (`pulumi.Input[str]`)
                    * `port` (`pulumi.Input[str]`)
                    * `soapRoundtripCount` (`pulumi.Input[float]`)
                    * `user` (`pulumi.Input[str]`)

                  * `network` (`pulumi.Input[dict]`)
                    * `publicNetwork` (`pulumi.Input[str]`)

                  * `virtualCenters` (`pulumi.Input[list]`)
                    * `datacenters` (`pulumi.Input[str]`)
                    * `name` (`pulumi.Input[str]`) - The cluster template revision name (string)
                    * `password` (`pulumi.Input[str]`)
                    * `port` (`pulumi.Input[str]`)
                    * `soapRoundtripCount` (`pulumi.Input[float]`)
                    * `user` (`pulumi.Input[str]`)

                  * `workspace` (`pulumi.Input[dict]`)
                    * `datacenter` (`pulumi.Input[str]`)
                    * `defaultDatastore` (`pulumi.Input[str]`)
                    * `folder` (`pulumi.Input[str]`)
                    * `resourcepoolPath` (`pulumi.Input[str]`)
                    * `server` (`pulumi.Input[str]`)

              * `dns` (`pulumi.Input[dict]`)
                * `nodeSelector` (`pulumi.Input[dict]`)
                * `provider` (`pulumi.Input[str]`)
                * `reverseCidrs` (`pulumi.Input[list]`)
                * `upstreamNameservers` (`pulumi.Input[list]`)

              * `ignoreDockerVersion` (`pulumi.Input[bool]`)
              * `ingress` (`pulumi.Input[dict]`)
                * `dnsPolicy` (`pulumi.Input[str]`)
                * `extraArgs` (`pulumi.Input[dict]`)
                * `nodeSelector` (`pulumi.Input[dict]`)
                * `options` (`pulumi.Input[dict]`)
                * `provider` (`pulumi.Input[str]`)

              * `kubernetesVersion` (`pulumi.Input[str]`)
              * `monitoring` (`pulumi.Input[dict]`)
                * `options` (`pulumi.Input[dict]`)
                * `provider` (`pulumi.Input[str]`)

              * `network` (`pulumi.Input[dict]`)
                * `calicoNetworkProvider` (`pulumi.Input[dict]`)
                  * `cloudProvider` (`pulumi.Input[str]`)

                * `canalNetworkProvider` (`pulumi.Input[dict]`)
                  * `iface` (`pulumi.Input[str]`)

                * `flannelNetworkProvider` (`pulumi.Input[dict]`)
                  * `iface` (`pulumi.Input[str]`)

                * `mtu` (`pulumi.Input[float]`)
                * `options` (`pulumi.Input[dict]`)
                * `plugin` (`pulumi.Input[str]`)
                * `weaveNetworkProvider` (`pulumi.Input[dict]`)
                  * `password` (`pulumi.Input[str]`)

              * `nodes` (`pulumi.Input[list]`)
                * `address` (`pulumi.Input[str]`)
                * `dockerSocket` (`pulumi.Input[str]`)
                * `hostnameOverride` (`pulumi.Input[str]`)
                * `internalAddress` (`pulumi.Input[str]`)
                * `labels` (`pulumi.Input[dict]`) - Labels for the cluster template revision (map)
                * `nodeId` (`pulumi.Input[str]`)
                * `port` (`pulumi.Input[str]`)
                * `roles` (`pulumi.Input[list]`)
                * `sshAgentAuth` (`pulumi.Input[bool]`)
                * `sshKey` (`pulumi.Input[str]`)
                * `sshKeyPath` (`pulumi.Input[str]`)
                * `user` (`pulumi.Input[str]`)

              * `prefixPath` (`pulumi.Input[str]`)
              * `privateRegistries` (`pulumi.Input[list]`)
                * `isDefault` (`pulumi.Input[bool]`)
                * `password` (`pulumi.Input[str]`)
                * `url` (`pulumi.Input[str]`)
                * `user` (`pulumi.Input[str]`)

              * `services` (`pulumi.Input[dict]`)
                * `etcd` (`pulumi.Input[dict]`)
                  * `backup_config` (`pulumi.Input[dict]`)
                    * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)
                    * `intervalHours` (`pulumi.Input[float]`)
                    * `retention` (`pulumi.Input[float]`)
                    * `s3BackupConfig` (`pulumi.Input[dict]`)
                      * `access_key` (`pulumi.Input[str]`)
                      * `bucketName` (`pulumi.Input[str]`)
                      * `customCa` (`pulumi.Input[str]`)
                      * `endpoint` (`pulumi.Input[str]`)
                      * `folder` (`pulumi.Input[str]`)
                      * `region` (`pulumi.Input[str]`)
                      * `secret_key` (`pulumi.Input[str]`)

                    * `safeTimestamp` (`pulumi.Input[bool]`)

                  * `caCert` (`pulumi.Input[str]`)
                  * `cert` (`pulumi.Input[str]`)
                  * `creation` (`pulumi.Input[str]`)
                  * `externalUrls` (`pulumi.Input[list]`)
                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `gid` (`pulumi.Input[float]`)
                  * `image` (`pulumi.Input[str]`)
                  * `key` (`pulumi.Input[str]`)
                  * `path` (`pulumi.Input[str]`)
                  * `retention` (`pulumi.Input[str]`)
                  * `snapshot` (`pulumi.Input[bool]`)
                  * `uid` (`pulumi.Input[float]`)

                * `kubeApi` (`pulumi.Input[dict]`)
                  * `admissionConfiguration` (`pulumi.Input[dict]`)
                  * `alwaysPullImages` (`pulumi.Input[bool]`)
                  * `auditLog` (`pulumi.Input[dict]`)
                    * `configuration` (`pulumi.Input[dict]`)
                      * `format` (`pulumi.Input[str]`)
                      * `maxAge` (`pulumi.Input[float]`)
                      * `maxBackup` (`pulumi.Input[float]`)
                      * `maxSize` (`pulumi.Input[float]`)
                      * `path` (`pulumi.Input[str]`)
                      * `policy` (`pulumi.Input[str]`)

                    * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)

                  * `eventRateLimit` (`pulumi.Input[dict]`)
                    * `configuration` (`pulumi.Input[dict]`)
                    * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)

                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `image` (`pulumi.Input[str]`)
                  * `podSecurityPolicy` (`pulumi.Input[bool]`)
                  * `secretsEncryptionConfig` (`pulumi.Input[dict]`)
                    * `customConfig` (`pulumi.Input[dict]`)
                    * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)

                  * `serviceClusterIpRange` (`pulumi.Input[str]`)
                  * `serviceNodePortRange` (`pulumi.Input[str]`)

                * `kubeController` (`pulumi.Input[dict]`)
                  * `clusterCidr` (`pulumi.Input[str]`)
                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `image` (`pulumi.Input[str]`)
                  * `serviceClusterIpRange` (`pulumi.Input[str]`)

                * `kubelet` (`pulumi.Input[dict]`)
                  * `clusterDnsServer` (`pulumi.Input[str]`)
                  * `clusterDomain` (`pulumi.Input[str]`)
                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `failSwapOn` (`pulumi.Input[bool]`)
                  * `generateServingCertificate` (`pulumi.Input[bool]`)
                  * `image` (`pulumi.Input[str]`)
                  * `infraContainerImage` (`pulumi.Input[str]`)

                * `kubeproxy` (`pulumi.Input[dict]`)
                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `image` (`pulumi.Input[str]`)

                * `scheduler` (`pulumi.Input[dict]`)
                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `image` (`pulumi.Input[str]`)

              * `sshAgentAuth` (`pulumi.Input[bool]`)
              * `sshCertPath` (`pulumi.Input[str]`)
              * `sshKeyPath` (`pulumi.Input[str]`)
              * `upgrade_strategy` (`pulumi.Input[dict]`)
                * `drain` (`pulumi.Input[bool]`)
                * `drainInput` (`pulumi.Input[dict]`)
                  * `deleteLocalData` (`pulumi.Input[bool]`)
                  * `force` (`pulumi.Input[bool]`)
                  * `gracePeriod` (`pulumi.Input[float]`)
                  * `ignoreDaemonSets` (`pulumi.Input[bool]`)
                  * `timeout` (`pulumi.Input[float]`)

                * `maxUnavailableControlplane` (`pulumi.Input[str]`)
                * `maxUnavailableWorker` (`pulumi.Input[str]`)

            * `scheduled_cluster_scan` (`pulumi.Input[dict]`) - Cluster scheduled cis scan. For Rancher v2.4.0 or above (List MaxItem:1)
              * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)
              * `scanConfig` (`pulumi.Input[dict]`)
                * `cisScanConfig` (`pulumi.Input[dict]`)
                  * `debugMaster` (`pulumi.Input[bool]`)
                  * `debugWorker` (`pulumi.Input[bool]`)
                  * `overrideBenchmarkVersion` (`pulumi.Input[str]`)
                  * `overrideSkips` (`pulumi.Input[list]`)
                  * `profile` (`pulumi.Input[str]`)

              * `scheduleConfig` (`pulumi.Input[dict]`)
                * `cronSchedule` (`pulumi.Input[str]`)
                * `retention` (`pulumi.Input[float]`)

            * `windows_prefered_cluster` (`pulumi.Input[bool]`) - Windows prefered cluster. Default: `false` (bool)

          * `cluster_template_id` (`pulumi.Input[str]`) - Cluster template ID (string)
          * `default` (`pulumi.Input[bool]`) - Default variable value (string)
          * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)
          * `id` (`pulumi.Input[str]`) - The cluster template revision ID (string)
          * `labels` (`pulumi.Input[dict]`) - Labels for the cluster template revision (map)
          * `name` (`pulumi.Input[str]`) - The cluster template revision name (string)
          * `questions` (`pulumi.Input[list]`) - Cluster template questions (list)
            * `default` (`pulumi.Input[str]`) - Default variable value (string)
            * `required` (`pulumi.Input[bool]`) - Required variable. Default `false` (bool)
            * `type` (`pulumi.Input[str]`) - Variable type. `boolean`, `int` and `string` are allowed. Default `string` (string)
            * `variable` (`pulumi.Input[str]`) - Variable name (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            __props__['description'] = description
            __props__['labels'] = labels
            __props__['members'] = members
            __props__['name'] = name
            __props__['template_revisions'] = template_revisions
            __props__['default_revision_id'] = None
        super(ClusterTemplate, __self__).__init__(
            'rancher2:index/clusterTemplate:ClusterTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, default_revision_id=None, description=None, labels=None, members=None, name=None, template_revisions=None):
        """
        Get an existing ClusterTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for the cluster template revision (map)
        :param pulumi.Input[str] default_revision_id: (Computed) Default cluster template revision ID (string)
        :param pulumi.Input[str] description: Cluster template description
        :param pulumi.Input[dict] labels: Labels for the cluster template revision (map)
        :param pulumi.Input[list] members: Cluster template members (list)
        :param pulumi.Input[str] name: The cluster template revision name (string)
        :param pulumi.Input[list] template_revisions: Cluster template revisions (list)

        The **members** object supports the following:

          * `accessType` (`pulumi.Input[str]`) - Member access type. Valid values: `["read-only" | "owner"]` (string)
          * `group_principal_id` (`pulumi.Input[str]`) - Member group principal id (string)
          * `user_principal_id` (`pulumi.Input[str]`) - Member user principal id (string)

        The **template_revisions** object supports the following:

          * `annotations` (`pulumi.Input[dict]`) - Annotations for the cluster template revision (map)
          * `clusterConfig` (`pulumi.Input[dict]`) - Cluster configuration (list maxitem: 1)
            * `cluster_auth_endpoint` (`pulumi.Input[dict]`) - Local cluster auth endpoint (list maxitems: 1)
              * `ca_certs` (`pulumi.Input[str]`)
              * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)
              * `fqdn` (`pulumi.Input[str]`)

            * `defaultClusterRoleForProjectMembers` (`pulumi.Input[str]`) - Default cluster role for project members (string)
            * `default_pod_security_policy_template_id` (`pulumi.Input[str]`) - Default pod security policy template ID (string)
            * `desired_agent_image` (`pulumi.Input[str]`) - Desired agent image (string)
            * `desired_auth_image` (`pulumi.Input[str]`) - Desired auth image (string)
            * `docker_root_dir` (`pulumi.Input[str]`) - Desired auth image (string)
            * `enable_cluster_alerting` (`pulumi.Input[bool]`) - Enable built-in cluster alerting. Default: `false` (bool)
            * `enable_cluster_monitoring` (`pulumi.Input[bool]`) - Enable built-in cluster monitoring. Default: `false` (bool)
            * `enable_network_policy` (`pulumi.Input[bool]`) - Enable project network isolation. Default: `false` (bool)
            * `rke_config` (`pulumi.Input[dict]`) - Rancher Kubernetes Engine Config (list maxitems: 1)
              * `addonJobTimeout` (`pulumi.Input[float]`)
              * `addons` (`pulumi.Input[str]`)
              * `addonsIncludes` (`pulumi.Input[list]`)
              * `authentication` (`pulumi.Input[dict]`)
                * `sans` (`pulumi.Input[list]`)
                * `strategy` (`pulumi.Input[str]`)

              * `authorization` (`pulumi.Input[dict]`)
                * `mode` (`pulumi.Input[str]`)
                * `options` (`pulumi.Input[dict]`)

              * `bastionHost` (`pulumi.Input[dict]`)
                * `address` (`pulumi.Input[str]`)
                * `port` (`pulumi.Input[str]`)
                * `sshAgentAuth` (`pulumi.Input[bool]`)
                * `sshKey` (`pulumi.Input[str]`)
                * `sshKeyPath` (`pulumi.Input[str]`)
                * `user` (`pulumi.Input[str]`)

              * `cloudProvider` (`pulumi.Input[dict]`)
                * `awsCloudProvider` (`pulumi.Input[dict]`)
                  * `global` (`pulumi.Input[dict]`)
                    * `disableSecurityGroupIngress` (`pulumi.Input[bool]`)
                    * `disableStrictZoneCheck` (`pulumi.Input[bool]`)
                    * `elbSecurityGroup` (`pulumi.Input[str]`)
                    * `kubernetesClusterId` (`pulumi.Input[str]`)
                    * `kubernetesClusterTag` (`pulumi.Input[str]`)
                    * `roleArn` (`pulumi.Input[str]`)
                    * `routeTableId` (`pulumi.Input[str]`)
                    * `subnetId` (`pulumi.Input[str]`)
                    * `vpc` (`pulumi.Input[str]`)
                    * `zone` (`pulumi.Input[str]`)

                  * `serviceOverrides` (`pulumi.Input[list]`)
                    * `region` (`pulumi.Input[str]`)
                    * `service` (`pulumi.Input[str]`)
                    * `signingMethod` (`pulumi.Input[str]`)
                    * `signingName` (`pulumi.Input[str]`)
                    * `signingRegion` (`pulumi.Input[str]`)
                    * `url` (`pulumi.Input[str]`)

                * `azureCloudProvider` (`pulumi.Input[dict]`)
                  * `aadClientCertPassword` (`pulumi.Input[str]`)
                  * `aadClientCertPath` (`pulumi.Input[str]`)
                  * `aadClientId` (`pulumi.Input[str]`)
                  * `aadClientSecret` (`pulumi.Input[str]`)
                  * `cloud` (`pulumi.Input[str]`)
                  * `cloudProviderBackoff` (`pulumi.Input[bool]`)
                  * `cloudProviderBackoffDuration` (`pulumi.Input[float]`)
                  * `cloudProviderBackoffExponent` (`pulumi.Input[float]`)
                  * `cloudProviderBackoffJitter` (`pulumi.Input[float]`)
                  * `cloudProviderBackoffRetries` (`pulumi.Input[float]`)
                  * `cloudProviderRateLimit` (`pulumi.Input[bool]`)
                  * `cloudProviderRateLimitBucket` (`pulumi.Input[float]`)
                  * `cloudProviderRateLimitQps` (`pulumi.Input[float]`)
                  * `location` (`pulumi.Input[str]`)
                  * `maximumLoadBalancerRuleCount` (`pulumi.Input[float]`)
                  * `primaryAvailabilitySetName` (`pulumi.Input[str]`)
                  * `primaryScaleSetName` (`pulumi.Input[str]`)
                  * `resourceGroup` (`pulumi.Input[str]`)
                  * `routeTableName` (`pulumi.Input[str]`)
                  * `securityGroupName` (`pulumi.Input[str]`)
                  * `subnetName` (`pulumi.Input[str]`)
                  * `subscriptionId` (`pulumi.Input[str]`)
                  * `tenant_id` (`pulumi.Input[str]`)
                  * `useInstanceMetadata` (`pulumi.Input[bool]`)
                  * `useManagedIdentityExtension` (`pulumi.Input[bool]`)
                  * `vmType` (`pulumi.Input[str]`)
                  * `vnetName` (`pulumi.Input[str]`)
                  * `vnetResourceGroup` (`pulumi.Input[str]`)

                * `customCloudProvider` (`pulumi.Input[str]`)
                * `name` (`pulumi.Input[str]`) - The cluster template revision name (string)
                * `openstackCloudProvider` (`pulumi.Input[dict]`)
                  * `blockStorage` (`pulumi.Input[dict]`)
                    * `bsVersion` (`pulumi.Input[str]`)
                    * `ignoreVolumeAz` (`pulumi.Input[bool]`)
                    * `trustDevicePath` (`pulumi.Input[bool]`)

                  * `global` (`pulumi.Input[dict]`)
                    * `authUrl` (`pulumi.Input[str]`)
                    * `caFile` (`pulumi.Input[str]`)
                    * `domainId` (`pulumi.Input[str]`)
                    * `domainName` (`pulumi.Input[str]`)
                    * `password` (`pulumi.Input[str]`)
                    * `region` (`pulumi.Input[str]`)
                    * `tenant_id` (`pulumi.Input[str]`)
                    * `tenantName` (`pulumi.Input[str]`)
                    * `trustId` (`pulumi.Input[str]`)
                    * `username` (`pulumi.Input[str]`)

                  * `loadBalancer` (`pulumi.Input[dict]`)
                    * `createMonitor` (`pulumi.Input[bool]`)
                    * `floatingNetworkId` (`pulumi.Input[str]`)
                    * `lbMethod` (`pulumi.Input[str]`)
                    * `lbProvider` (`pulumi.Input[str]`)
                    * `lbVersion` (`pulumi.Input[str]`)
                    * `manageSecurityGroups` (`pulumi.Input[bool]`)
                    * `monitorDelay` (`pulumi.Input[str]`)
                    * `monitorMaxRetries` (`pulumi.Input[float]`)
                    * `monitorTimeout` (`pulumi.Input[str]`)
                    * `subnetId` (`pulumi.Input[str]`)
                    * `useOctavia` (`pulumi.Input[bool]`)

                  * `metadata` (`pulumi.Input[dict]`)
                    * `requestTimeout` (`pulumi.Input[float]`)
                    * `searchOrder` (`pulumi.Input[str]`)

                  * `route` (`pulumi.Input[dict]`)
                    * `routerId` (`pulumi.Input[str]`)

                * `vsphereCloudProvider` (`pulumi.Input[dict]`)
                  * `disk` (`pulumi.Input[dict]`)
                    * `scsiControllerType` (`pulumi.Input[str]`)

                  * `global` (`pulumi.Input[dict]`)
                    * `datacenters` (`pulumi.Input[str]`)
                    * `insecureFlag` (`pulumi.Input[bool]`)
                    * `password` (`pulumi.Input[str]`)
                    * `port` (`pulumi.Input[str]`)
                    * `soapRoundtripCount` (`pulumi.Input[float]`)
                    * `user` (`pulumi.Input[str]`)

                  * `network` (`pulumi.Input[dict]`)
                    * `publicNetwork` (`pulumi.Input[str]`)

                  * `virtualCenters` (`pulumi.Input[list]`)
                    * `datacenters` (`pulumi.Input[str]`)
                    * `name` (`pulumi.Input[str]`) - The cluster template revision name (string)
                    * `password` (`pulumi.Input[str]`)
                    * `port` (`pulumi.Input[str]`)
                    * `soapRoundtripCount` (`pulumi.Input[float]`)
                    * `user` (`pulumi.Input[str]`)

                  * `workspace` (`pulumi.Input[dict]`)
                    * `datacenter` (`pulumi.Input[str]`)
                    * `defaultDatastore` (`pulumi.Input[str]`)
                    * `folder` (`pulumi.Input[str]`)
                    * `resourcepoolPath` (`pulumi.Input[str]`)
                    * `server` (`pulumi.Input[str]`)

              * `dns` (`pulumi.Input[dict]`)
                * `nodeSelector` (`pulumi.Input[dict]`)
                * `provider` (`pulumi.Input[str]`)
                * `reverseCidrs` (`pulumi.Input[list]`)
                * `upstreamNameservers` (`pulumi.Input[list]`)

              * `ignoreDockerVersion` (`pulumi.Input[bool]`)
              * `ingress` (`pulumi.Input[dict]`)
                * `dnsPolicy` (`pulumi.Input[str]`)
                * `extraArgs` (`pulumi.Input[dict]`)
                * `nodeSelector` (`pulumi.Input[dict]`)
                * `options` (`pulumi.Input[dict]`)
                * `provider` (`pulumi.Input[str]`)

              * `kubernetesVersion` (`pulumi.Input[str]`)
              * `monitoring` (`pulumi.Input[dict]`)
                * `options` (`pulumi.Input[dict]`)
                * `provider` (`pulumi.Input[str]`)

              * `network` (`pulumi.Input[dict]`)
                * `calicoNetworkProvider` (`pulumi.Input[dict]`)
                  * `cloudProvider` (`pulumi.Input[str]`)

                * `canalNetworkProvider` (`pulumi.Input[dict]`)
                  * `iface` (`pulumi.Input[str]`)

                * `flannelNetworkProvider` (`pulumi.Input[dict]`)
                  * `iface` (`pulumi.Input[str]`)

                * `mtu` (`pulumi.Input[float]`)
                * `options` (`pulumi.Input[dict]`)
                * `plugin` (`pulumi.Input[str]`)
                * `weaveNetworkProvider` (`pulumi.Input[dict]`)
                  * `password` (`pulumi.Input[str]`)

              * `nodes` (`pulumi.Input[list]`)
                * `address` (`pulumi.Input[str]`)
                * `dockerSocket` (`pulumi.Input[str]`)
                * `hostnameOverride` (`pulumi.Input[str]`)
                * `internalAddress` (`pulumi.Input[str]`)
                * `labels` (`pulumi.Input[dict]`) - Labels for the cluster template revision (map)
                * `nodeId` (`pulumi.Input[str]`)
                * `port` (`pulumi.Input[str]`)
                * `roles` (`pulumi.Input[list]`)
                * `sshAgentAuth` (`pulumi.Input[bool]`)
                * `sshKey` (`pulumi.Input[str]`)
                * `sshKeyPath` (`pulumi.Input[str]`)
                * `user` (`pulumi.Input[str]`)

              * `prefixPath` (`pulumi.Input[str]`)
              * `privateRegistries` (`pulumi.Input[list]`)
                * `isDefault` (`pulumi.Input[bool]`)
                * `password` (`pulumi.Input[str]`)
                * `url` (`pulumi.Input[str]`)
                * `user` (`pulumi.Input[str]`)

              * `services` (`pulumi.Input[dict]`)
                * `etcd` (`pulumi.Input[dict]`)
                  * `backup_config` (`pulumi.Input[dict]`)
                    * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)
                    * `intervalHours` (`pulumi.Input[float]`)
                    * `retention` (`pulumi.Input[float]`)
                    * `s3BackupConfig` (`pulumi.Input[dict]`)
                      * `access_key` (`pulumi.Input[str]`)
                      * `bucketName` (`pulumi.Input[str]`)
                      * `customCa` (`pulumi.Input[str]`)
                      * `endpoint` (`pulumi.Input[str]`)
                      * `folder` (`pulumi.Input[str]`)
                      * `region` (`pulumi.Input[str]`)
                      * `secret_key` (`pulumi.Input[str]`)

                    * `safeTimestamp` (`pulumi.Input[bool]`)

                  * `caCert` (`pulumi.Input[str]`)
                  * `cert` (`pulumi.Input[str]`)
                  * `creation` (`pulumi.Input[str]`)
                  * `externalUrls` (`pulumi.Input[list]`)
                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `gid` (`pulumi.Input[float]`)
                  * `image` (`pulumi.Input[str]`)
                  * `key` (`pulumi.Input[str]`)
                  * `path` (`pulumi.Input[str]`)
                  * `retention` (`pulumi.Input[str]`)
                  * `snapshot` (`pulumi.Input[bool]`)
                  * `uid` (`pulumi.Input[float]`)

                * `kubeApi` (`pulumi.Input[dict]`)
                  * `admissionConfiguration` (`pulumi.Input[dict]`)
                  * `alwaysPullImages` (`pulumi.Input[bool]`)
                  * `auditLog` (`pulumi.Input[dict]`)
                    * `configuration` (`pulumi.Input[dict]`)
                      * `format` (`pulumi.Input[str]`)
                      * `maxAge` (`pulumi.Input[float]`)
                      * `maxBackup` (`pulumi.Input[float]`)
                      * `maxSize` (`pulumi.Input[float]`)
                      * `path` (`pulumi.Input[str]`)
                      * `policy` (`pulumi.Input[str]`)

                    * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)

                  * `eventRateLimit` (`pulumi.Input[dict]`)
                    * `configuration` (`pulumi.Input[dict]`)
                    * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)

                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `image` (`pulumi.Input[str]`)
                  * `podSecurityPolicy` (`pulumi.Input[bool]`)
                  * `secretsEncryptionConfig` (`pulumi.Input[dict]`)
                    * `customConfig` (`pulumi.Input[dict]`)
                    * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)

                  * `serviceClusterIpRange` (`pulumi.Input[str]`)
                  * `serviceNodePortRange` (`pulumi.Input[str]`)

                * `kubeController` (`pulumi.Input[dict]`)
                  * `clusterCidr` (`pulumi.Input[str]`)
                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `image` (`pulumi.Input[str]`)
                  * `serviceClusterIpRange` (`pulumi.Input[str]`)

                * `kubelet` (`pulumi.Input[dict]`)
                  * `clusterDnsServer` (`pulumi.Input[str]`)
                  * `clusterDomain` (`pulumi.Input[str]`)
                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `failSwapOn` (`pulumi.Input[bool]`)
                  * `generateServingCertificate` (`pulumi.Input[bool]`)
                  * `image` (`pulumi.Input[str]`)
                  * `infraContainerImage` (`pulumi.Input[str]`)

                * `kubeproxy` (`pulumi.Input[dict]`)
                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `image` (`pulumi.Input[str]`)

                * `scheduler` (`pulumi.Input[dict]`)
                  * `extraArgs` (`pulumi.Input[dict]`)
                  * `extraBinds` (`pulumi.Input[list]`)
                  * `extraEnvs` (`pulumi.Input[list]`)
                  * `image` (`pulumi.Input[str]`)

              * `sshAgentAuth` (`pulumi.Input[bool]`)
              * `sshCertPath` (`pulumi.Input[str]`)
              * `sshKeyPath` (`pulumi.Input[str]`)
              * `upgrade_strategy` (`pulumi.Input[dict]`)
                * `drain` (`pulumi.Input[bool]`)
                * `drainInput` (`pulumi.Input[dict]`)
                  * `deleteLocalData` (`pulumi.Input[bool]`)
                  * `force` (`pulumi.Input[bool]`)
                  * `gracePeriod` (`pulumi.Input[float]`)
                  * `ignoreDaemonSets` (`pulumi.Input[bool]`)
                  * `timeout` (`pulumi.Input[float]`)

                * `maxUnavailableControlplane` (`pulumi.Input[str]`)
                * `maxUnavailableWorker` (`pulumi.Input[str]`)

            * `scheduled_cluster_scan` (`pulumi.Input[dict]`) - Cluster scheduled cis scan. For Rancher v2.4.0 or above (List MaxItem:1)
              * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)
              * `scanConfig` (`pulumi.Input[dict]`)
                * `cisScanConfig` (`pulumi.Input[dict]`)
                  * `debugMaster` (`pulumi.Input[bool]`)
                  * `debugWorker` (`pulumi.Input[bool]`)
                  * `overrideBenchmarkVersion` (`pulumi.Input[str]`)
                  * `overrideSkips` (`pulumi.Input[list]`)
                  * `profile` (`pulumi.Input[str]`)

              * `scheduleConfig` (`pulumi.Input[dict]`)
                * `cronSchedule` (`pulumi.Input[str]`)
                * `retention` (`pulumi.Input[float]`)

            * `windows_prefered_cluster` (`pulumi.Input[bool]`) - Windows prefered cluster. Default: `false` (bool)

          * `cluster_template_id` (`pulumi.Input[str]`) - Cluster template ID (string)
          * `default` (`pulumi.Input[bool]`) - Default variable value (string)
          * `enabled` (`pulumi.Input[bool]`) - Enable cluster template revision. Default `true` (bool)
          * `id` (`pulumi.Input[str]`) - The cluster template revision ID (string)
          * `labels` (`pulumi.Input[dict]`) - Labels for the cluster template revision (map)
          * `name` (`pulumi.Input[str]`) - The cluster template revision name (string)
          * `questions` (`pulumi.Input[list]`) - Cluster template questions (list)
            * `default` (`pulumi.Input[str]`) - Default variable value (string)
            * `required` (`pulumi.Input[bool]`) - Required variable. Default `false` (bool)
            * `type` (`pulumi.Input[str]`) - Variable type. `boolean`, `int` and `string` are allowed. Default `string` (string)
            * `variable` (`pulumi.Input[str]`) - Variable name (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["default_revision_id"] = default_revision_id
        __props__["description"] = description
        __props__["labels"] = labels
        __props__["members"] = members
        __props__["name"] = name
        __props__["template_revisions"] = template_revisions
        return ClusterTemplate(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetNodeTemplateResult:
    """
    A collection of values returned by getNodeTemplate.
    """
    def __init__(__self__, annotations=None, cloud_credential_id=None, description=None, driver=None, engine_env=None, engine_insecure_registries=None, engine_install_url=None, engine_label=None, engine_opt=None, engine_registry_mirrors=None, engine_storage_driver=None, id=None, labels=None, name=None, use_internal_ip_address=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for Node Template object (map)
        """
        if cloud_credential_id and not isinstance(cloud_credential_id, str):
            raise TypeError("Expected argument 'cloud_credential_id' to be a str")
        __self__.cloud_credential_id = cloud_credential_id
        """
        (Computed) Cloud credential ID for the Node Template. Required from Rancher v2.2.x (string)
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        (Computed) Description for the Node Template (string)
        """
        if driver and not isinstance(driver, str):
            raise TypeError("Expected argument 'driver' to be a str")
        __self__.driver = driver
        """
        (Computed) The driver of the node template (string)
        """
        if engine_env and not isinstance(engine_env, dict):
            raise TypeError("Expected argument 'engine_env' to be a dict")
        __self__.engine_env = engine_env
        """
        (Computed) Engine environment for the node template (string)
        """
        if engine_insecure_registries and not isinstance(engine_insecure_registries, list):
            raise TypeError("Expected argument 'engine_insecure_registries' to be a list")
        __self__.engine_insecure_registries = engine_insecure_registries
        """
        (Computed) Insecure registry for the node template (list)
        """
        if engine_install_url and not isinstance(engine_install_url, str):
            raise TypeError("Expected argument 'engine_install_url' to be a str")
        __self__.engine_install_url = engine_install_url
        """
        (Computed) Docker engine install URL for the node template (string)
        """
        if engine_label and not isinstance(engine_label, dict):
            raise TypeError("Expected argument 'engine_label' to be a dict")
        __self__.engine_label = engine_label
        """
        (Computed) Engine label for the node template (string)
        """
        if engine_opt and not isinstance(engine_opt, dict):
            raise TypeError("Expected argument 'engine_opt' to be a dict")
        __self__.engine_opt = engine_opt
        """
        (Computed) Engine options for the node template (map)
        """
        if engine_registry_mirrors and not isinstance(engine_registry_mirrors, list):
            raise TypeError("Expected argument 'engine_registry_mirrors' to be a list")
        __self__.engine_registry_mirrors = engine_registry_mirrors
        """
        (Computed) Engine registry mirror for the node template (list)
        """
        if engine_storage_driver and not isinstance(engine_storage_driver, str):
            raise TypeError("Expected argument 'engine_storage_driver' to be a str")
        __self__.engine_storage_driver = engine_storage_driver
        """
        (Computed) Engine storage driver for the node template (string)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for Node Template object (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if use_internal_ip_address and not isinstance(use_internal_ip_address, bool):
            raise TypeError("Expected argument 'use_internal_ip_address' to be a bool")
        __self__.use_internal_ip_address = use_internal_ip_address
        """
        (Computed) Engine storage driver for the node template (bool)
        """
class AwaitableGetNodeTemplateResult(GetNodeTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNodeTemplateResult(
            annotations=self.annotations,
            cloud_credential_id=self.cloud_credential_id,
            description=self.description,
            driver=self.driver,
            engine_env=self.engine_env,
            engine_insecure_registries=self.engine_insecure_registries,
            engine_install_url=self.engine_install_url,
            engine_label=self.engine_label,
            engine_opt=self.engine_opt,
            engine_registry_mirrors=self.engine_registry_mirrors,
            engine_storage_driver=self.engine_storage_driver,
            id=self.id,
            labels=self.labels,
            name=self.name,
            use_internal_ip_address=self.use_internal_ip_address)

def get_node_template(name=None,use_internal_ip_address=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 Node Template resource.




    :param str name: The name of the Node Template (string)
    :param bool use_internal_ip_address: (Computed) Engine storage driver for the node template (bool)
    """
    __args__ = dict()


    __args__['name'] = name
    __args__['useInternalIpAddress'] = use_internal_ip_address
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getNodeTemplate:getNodeTemplate', __args__, opts=opts).value

    return AwaitableGetNodeTemplateResult(
        annotations=__ret__.get('annotations'),
        cloud_credential_id=__ret__.get('cloudCredentialId'),
        description=__ret__.get('description'),
        driver=__ret__.get('driver'),
        engine_env=__ret__.get('engineEnv'),
        engine_insecure_registries=__ret__.get('engineInsecureRegistries'),
        engine_install_url=__ret__.get('engineInstallUrl'),
        engine_label=__ret__.get('engineLabel'),
        engine_opt=__ret__.get('engineOpt'),
        engine_registry_mirrors=__ret__.get('engineRegistryMirrors'),
        engine_storage_driver=__ret__.get('engineStorageDriver'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        use_internal_ip_address=__ret__.get('useInternalIpAddress'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetProjectAlertRuleResult:
    """
    A collection of values returned by getProjectAlertRule.
    """
    def __init__(__self__, annotations=None, group_id=None, group_interval_seconds=None, group_wait_seconds=None, id=None, inherited=None, labels=None, metric_rule=None, name=None, pod_rule=None, project_id=None, repeat_interval_seconds=None, severity=None, workload_rule=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) The project alert rule annotations (map)
        """
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        __self__.group_id = group_id
        """
        (Computed) The project alert rule alert group ID (string)
        """
        if group_interval_seconds and not isinstance(group_interval_seconds, float):
            raise TypeError("Expected argument 'group_interval_seconds' to be a float")
        __self__.group_interval_seconds = group_interval_seconds
        """
        (Computed) The project alert rule group interval seconds. Default: `180` (int)
        """
        if group_wait_seconds and not isinstance(group_wait_seconds, float):
            raise TypeError("Expected argument 'group_wait_seconds' to be a float")
        __self__.group_wait_seconds = group_wait_seconds
        """
        (Computed) The project alert rule group wait seconds. Default: `180` (int)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if inherited and not isinstance(inherited, bool):
            raise TypeError("Expected argument 'inherited' to be a bool")
        __self__.inherited = inherited
        """
        (Computed) The project alert rule inherited. Default: `true` (bool)
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) The project alert rule labels (map)
        """
        if metric_rule and not isinstance(metric_rule, dict):
            raise TypeError("Expected argument 'metric_rule' to be a dict")
        __self__.metric_rule = metric_rule
        """
        (Computed) The project alert rule metric rule. ConflictsWith: `"pod_rule", "workload_rule"`` (list Maxitems:1)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if pod_rule and not isinstance(pod_rule, dict):
            raise TypeError("Expected argument 'pod_rule' to be a dict")
        __self__.pod_rule = pod_rule
        """
        (Computed) The project alert rule pod rule. ConflictsWith: `"metric_rule", "workload_rule"`` (list Maxitems:1)
        """
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        __self__.project_id = project_id
        if repeat_interval_seconds and not isinstance(repeat_interval_seconds, float):
            raise TypeError("Expected argument 'repeat_interval_seconds' to be a float")
        __self__.repeat_interval_seconds = repeat_interval_seconds
        """
        (Computed) The project alert rule wait seconds. Default: `3600` (int)
        """
        if severity and not isinstance(severity, str):
            raise TypeError("Expected argument 'severity' to be a str")
        __self__.severity = severity
        """
        (Computed) The project alert rule severity. Supported values : `"critical" | "info" | "warning"`. Default: `critical` (string)
        """
        if workload_rule and not isinstance(workload_rule, dict):
            raise TypeError("Expected argument 'workload_rule' to be a dict")
        __self__.workload_rule = workload_rule
        """
        (Computed) The project alert rule workload rule. ConflictsWith: `"metric_rule", "pod_rule"`` (list Maxitems:1)
        """
class AwaitableGetProjectAlertRuleResult(GetProjectAlertRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectAlertRuleResult(
            annotations=self.annotations,
            group_id=self.group_id,
            group_interval_seconds=self.group_interval_seconds,
            group_wait_seconds=self.group_wait_seconds,
            id=self.id,
            inherited=self.inherited,
            labels=self.labels,
            metric_rule=self.metric_rule,
            name=self.name,
            pod_rule=self.pod_rule,
            project_id=self.project_id,
            repeat_interval_seconds=self.repeat_interval_seconds,
            severity=self.severity,
            workload_rule=self.workload_rule)

def get_project_alert_rule(labels=None,name=None,project_id=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 project alert rule.




    :param dict labels: (Computed) The project alert rule labels (map)
    :param str name: The project alert rule name (string)
    :param str project_id: The project id where create project alert rule (string)
    """
    __args__ = dict()


    __args__['labels'] = labels
    __args__['name'] = name
    __args__['projectId'] = project_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getProjectAlertRule:getProjectAlertRule', __args__, opts=opts).value

    return AwaitableGetProjectAlertRuleResult(
        annotations=__ret__.get('annotations'),
        group_id=__ret__.get('groupId'),
        group_interval_seconds=__ret__.get('groupIntervalSeconds'),
        group_wait_seconds=__ret__.get('groupWaitSeconds'),
        id=__ret__.get('id'),
        inherited=__ret__.get('inherited'),
        labels=__ret__.get('labels'),
        metric_rule=__ret__.get('metricRule'),
        name=__ret__.get('name'),
        pod_rule=__ret__.get('podRule'),
        project_id=__ret__.get('projectId'),
        repeat_interval_seconds=__ret__.get('repeatIntervalSeconds'),
        severity=__ret__.get('severity'),
        workload_rule=__ret__.get('workloadRule'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetNotifierResult:
    """
    A collection of values returned by getNotifier.
    """
    def __init__(__self__, annotations=None, cluster_id=None, description=None, id=None, labels=None, name=None, pagerduty_config=None, slack_config=None, smtp_config=None, webhook_config=None, wechat_config=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for notifier object (map)
        """
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        __self__.cluster_id = cluster_id
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        (Computed) The notifier description (string)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for notifier object (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if pagerduty_config and not isinstance(pagerduty_config, dict):
            raise TypeError("Expected argument 'pagerduty_config' to be a dict")
        __self__.pagerduty_config = pagerduty_config
        """
        (Computed) Pagerduty config for notifier (list maxitems:1)
        """
        if slack_config and not isinstance(slack_config, dict):
            raise TypeError("Expected argument 'slack_config' to be a dict")
        __self__.slack_config = slack_config
        """
        (Computed) Slack config for notifier (list maxitems:1)
        """
        if smtp_config and not isinstance(smtp_config, dict):
            raise TypeError("Expected argument 'smtp_config' to be a dict")
        __self__.smtp_config = smtp_config
        """
        (Computed) SMTP config for notifier (list maxitems:1)
        """
        if webhook_config and not isinstance(webhook_config, dict):
            raise TypeError("Expected argument 'webhook_config' to be a dict")
        __self__.webhook_config = webhook_config
        """
        (Computed) Webhook config for notifier (list maxitems:1)
        """
        if wechat_config and not isinstance(wechat_config, dict):
            raise TypeError("Expected argument 'wechat_config' to be a dict")
        __self__.wechat_config = wechat_config
        """
        (Computed) Wechat config for notifier (list maxitems:1)
        """
class AwaitableGetNotifierResult(GetNotifierResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNotifierResult(
            annotations=self.annotations,
            cluster_id=self.cluster_id,
            description=self.description,
            id=self.id,
            labels=self.labels,
            name=self.name,
            pagerduty_config=self.pagerduty_config,
            slack_config=self.slack_config,
            smtp_config=self.smtp_config,
            webhook_config=self.webhook_config,
            wechat_config=self.wechat_config)

def get_notifier(cluster_id=None,name=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 notifier.




    :param str cluster_id: The cluster id where create notifier (string)
    :param str name: The name of the notifier (string)
    """
    __args__ = dict()


    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getNotifier:getNotifier', __args__, opts=opts).value

    return AwaitableGetNotifierResult(
        annotations=__ret__.get('annotations'),
        cluster_id=__ret__.get('clusterId'),
        description=__ret__.get('description'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        pagerduty_config=__ret__.get('pagerdutyConfig'),
        slack_config=__ret__.get('slackConfig'),
        smtp_config=__ret__.get('smtpConfig'),
        webhook_config=__ret__.get('webhookConfig'),
        wechat_config=__ret__.get('wechatConfig'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetProjectAlertGroupResult:
    """
    A collection of values returned by getProjectAlertGroup.
    """
    def __init__(__self__, annotations=None, description=None, group_interval_seconds=None, group_wait_seconds=None, id=None, labels=None, name=None, project_id=None, recipients=None, repeat_interval_seconds=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) The project alert group annotations (map)
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        (Computed) The project alert group description (string)
        """
        if group_interval_seconds and not isinstance(group_interval_seconds, float):
            raise TypeError("Expected argument 'group_interval_seconds' to be a float")
        __self__.group_interval_seconds = group_interval_seconds
        """
        (Computed) The project alert group interval seconds. Default: `180` (int)
        """
        if group_wait_seconds and not isinstance(group_wait_seconds, float):
            raise TypeError("Expected argument 'group_wait_seconds' to be a float")
        __self__.group_wait_seconds = group_wait_seconds
        """
        (Computed) The project alert group wait seconds. Default: `180` (int)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) The project alert group labels (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        __self__.project_id = project_id
        if recipients and not isinstance(recipients, list):
            raise TypeError("Expected argument 'recipients' to be a list")
        __self__.recipients = recipients
        """
        (Computed) The project alert group recipients (list)
        """
        if repeat_interval_seconds and not isinstance(repeat_interval_seconds, float):
            raise TypeError("Expected argument 'repeat_interval_seconds' to be a float")
        __self__.repeat_interval_seconds = repeat_interval_seconds
        """
        (Computed) The project alert group wait seconds. Default: `3600` (int)
        """
class AwaitableGetProjectAlertGroupResult(GetProjectAlertGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectAlertGroupResult(
            annotations=self.annotations,
            description=self.description,
            group_interval_seconds=self.group_interval_seconds,
            group_wait_seconds=self.group_wait_seconds,
            id=self.id,
            labels=self.labels,
            name=self.name,
            project_id=self.project_id,
            recipients=self.recipients,
            repeat_interval_seconds=self.repeat_interval_seconds)

def get_project_alert_group(name=None,project_id=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 project alert group.




    :param str name: The project alert group name (string)
    :param str project_id: The project id where create project alert group (string)
    """
    __args__ = dict()


    __args__['name'] = name
    __args__['projectId'] = project_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getProjectAlertGroup:getProjectAlertGroup', __args__, opts=opts).value

    return AwaitableGetProjectAlertGroupResult(
        annotations=__ret__.get('annotations'),
        description=__ret__.get('description'),
        group_interval_seconds=__ret__.get('groupIntervalSeconds'),
        group_wait_seconds=__ret__.get('groupWaitSeconds'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        project_id=__ret__.get('projectId'),
        recipients=__ret__.get('recipients'),
        repeat_interval_seconds=__ret__.get('repeatIntervalSeconds'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class Namespace(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for Node Pool object (map)
    """
    container_resource_limit: pulumi.Output[dict]
    """
    Default containers resource limits on namespace (List maxitem:1)

      * `limitsCpu` (`str`) - Limit for limits cpu in namespace (string)
      * `limitsMemory` (`str`) - Limit for limits memory in namespace (string)
      * `requestsCpu` (`str`) - Limit for requests cpu in namespace (string)
      * `requestsMemory` (`str`) - Limit for requests memory in namespace (string)
    """
    description: pulumi.Output[str]
    """
    A namespace description (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for Node Pool object (map)
    """
    name: pulumi.Output[str]
    """
    The name of the namespace (string)
    """
    project_id: pulumi.Output[str]
    """
    The project id where assign namespace. It's on the form `project_id=<cluster_id>:<id>`. Updating `<id>` part on same `<cluster_id>` namespace will be moved between projects (string)
    """
    resource_quota: pulumi.Output[dict]
    """
    Resource quota for namespace. Rancher v2.1.x or higher (list maxitems:1)

      * `limit` (`dict`) - Resource quota limit for namespace (list maxitems:1)
        * `configMaps` (`str`) - Limit for config maps in namespace (string)
        * `limitsCpu` (`str`) - Limit for limits cpu in namespace (string)
        * `limitsMemory` (`str`) - Limit for limits memory in namespace (string)
        * `persistentVolumeClaims` (`str`) - Limit for persistent volume claims in namespace (string)
        * `pods` (`str`) - Limit for pods in namespace (string)
        * `replicationControllers` (`str`) - Limit for replication controllers in namespace (string)
        * `requestsCpu` (`str`) - Limit for requests cpu in namespace (string)
        * `requestsMemory` (`str`) - Limit for requests memory in namespace (string)
        * `requestsStorage` (`str`) - Limit for requests storage in namespace (string)
        * `secrets` (`str`) - Limit for secrets in namespace (string)
        * `services` (`str`)
        * `servicesLoadBalancers` (`str`) - Limit for services load balancers in namespace (string)
        * `servicesNodePorts` (`str`) - Limit for services node ports in namespace (string)
    """
    wait_for_cluster: pulumi.Output[bool]
    """
    Wait for cluster becomes active. Default `false` (bool)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, container_resource_limit=None, description=None, labels=None, name=None, project_id=None, resource_quota=None, wait_for_cluster=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Namespace resource. This can be used to create namespaces for Rancher v2 environments and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Node Pool object (map)
        :param pulumi.Input[dict] container_resource_limit: Default containers resource limits on namespace (List maxitem:1)
        :param pulumi.Input[str] description: A namespace description (string)
        :param pulumi.Input[dict] labels: Labels for Node Pool object (map)
        :param pulumi.Input[str] name: The name of the namespace (string)
        :param pulumi.Input[str] project_id: The project id where assign namespace. It's on the form `project_id=<cluster_id>:<id>`. Updating `<id>` part on same `<cluster_id>` namespace will be moved between projects (string)
        :param pulumi.Input[dict] resource_quota: Resource quota for namespace. Rancher v2.1.x or higher (list maxitems:1)
        :param pulumi.Input[bool] wait_for_cluster: Wait for cluster becomes active. Default `false` (bool)

        The **container_resource_limit** object supports the following:

          * `limitsCpu` (`pulumi.Input[str]`) - Limit for limits cpu in namespace (string)
          * `limitsMemory` (`pulumi.Input[str]`) - Limit for limits memory in namespace (string)
          * `requestsCpu` (`pulumi.Input[str]`) - Limit for requests cpu in namespace (string)
          * `requestsMemory` (`pulumi.Input[str]`) - Limit for requests memory in namespace (string)

        The **resource_quota** object supports the following:

          * `limit` (`pulumi.Input[dict]`) - Resource quota limit for namespace (list maxitems:1)
            * `configMaps` (`pulumi.Input[str]`) - Limit for config maps in namespace (string)
            * `limitsCpu` (`pulumi.Input[str]`) - Limit for limits cpu in namespace (string)
            * `limitsMemory` (`pulumi.Input[str]`) - Limit for limits memory in namespace (string)
            * `persistentVolumeClaims` (`pulumi.Input[str]`) - Limit for persistent volume claims in namespace (string)
            * `pods` (`pulumi.Input[str]`) - Limit for pods in namespace (string)
            * `replicationControllers` (`pulumi.Input[str]`) - Limit for replication controllers in namespace (string)
            * `requestsCpu` (`pulumi.Input[str]`) - Limit for requests cpu in namespace (string)
            * `requestsMemory` (`pulumi.Input[str]`) - Limit for requests memory in namespace (string)
            * `requestsStorage` (`pulumi.Input[str]`) - Limit for requests storage in namespace (string)
            * `secrets` (`pulumi.Input[str]`) - Limit for secrets in namespace (string)
            * `services` (`pulumi.Input[str]`)
            * `servicesLoadBalancers` (`pulumi.Input[str]`) - Limit for services load balancers in namespace (string)
            * `servicesNodePorts` (`pulumi.Input[str]`) - Limit for services node ports in namespace (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            __props__['container_resource_limit'] = container_resource_limit
            __props__['description'] = description
            __props__['labels'] = labels
            __props__['name'] = name
            if project_id is None:
                raise TypeError("Missing required property 'project_id'")
            __props__['project_id'] = project_id
            __props__['resource_quota'] = resource_quota
            __props__['wait_for_cluster'] = wait_for_cluster
        super(Namespace, __self__).__init__(
            'rancher2:index/namespace:Namespace',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, container_resource_limit=None, description=None, labels=None, name=None, project_id=None, resource_quota=None, wait_for_cluster=None):
        """
        Get an existing Namespace resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Node Pool object (map)
        :param pulumi.Input[dict] container_resource_limit: Default containers resource limits on namespace (List maxitem:1)
        :param pulumi.Input[str] description: A namespace description (string)
        :param pulumi.Input[dict] labels: Labels for Node Pool object (map)
        :param pulumi.Input[str] name: The name of the namespace (string)
        :param pulumi.Input[str] project_id: The project id where assign namespace. It's on the form `project_id=<cluster_id>:<id>`. Updating `<id>` part on same `<cluster_id>` namespace will be moved between projects (string)
        :param pulumi.Input[dict] resource_quota: Resource quota for namespace. Rancher v2.1.x or higher (list maxitems:1)
        :param pulumi.Input[bool] wait_for_cluster: Wait for cluster becomes active. Default `false` (bool)

        The **container_resource_limit** object supports the following:

          * `limitsCpu` (`pulumi.Input[str]`) - Limit for limits cpu in namespace (string)
          * `limitsMemory` (`pulumi.Input[str]`) - Limit for limits memory in namespace (string)
          * `requestsCpu` (`pulumi.Input[str]`) - Limit for requests cpu in namespace (string)
          * `requestsMemory` (`pulumi.Input[str]`) - Limit for requests memory in namespace (string)

        The **resource_quota** object supports the following:

          * `limit` (`pulumi.Input[dict]`) - Resource quota limit for namespace (list maxitems:1)
            * `configMaps` (`pulumi.Input[str]`) - Limit for config maps in namespace (string)
            * `limitsCpu` (`pulumi.Input[str]`) - Limit for limits cpu in namespace (string)
            * `limitsMemory` (`pulumi.Input[str]`) - Limit for limits memory in namespace (string)
            * `persistentVolumeClaims` (`pulumi.Input[str]`) - Limit for persistent volume claims in namespace (string)
            * `pods` (`pulumi.Input[str]`) - Limit for pods in namespace (string)
            * `replicationControllers` (`pulumi.Input[str]`) - Limit for replication controllers in namespace (string)
            * `requestsCpu` (`pulumi.Input[str]`) - Limit for requests cpu in namespace (string)
            * `requestsMemory` (`pulumi.Input[str]`) - Limit for requests memory in namespace (string)
            * `requestsStorage` (`pulumi.Input[str]`) - Limit for requests storage in namespace (string)
            * `secrets` (`pulumi.Input[str]`) - Limit for secrets in namespace (string)
            * `services` (`pulumi.Input[str]`)
            * `servicesLoadBalancers` (`pulumi.Input[str]`) - Limit for services load balancers in namespace (string)
            * `servicesNodePorts` (`pulumi.Input[str]`) - Limit for services node ports in namespace (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["container_resource_limit"] = container_resource_limit
        __props__["description"] = description
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["project_id"] = project_id
        __props__["resource_quota"] = resource_quota
        __props__["wait_for_cluster"] = wait_for_cluster
        return Namespace(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class AuthConfigAzureAd(pulumi.CustomResource):
    access_mode: pulumi.Output[str]
    """
    Access mode for auth. `required`, `restricted`, `unrestricted` are supported. Default `unrestricted` (string)
    """
    allowed_principal_ids: pulumi.Output[list]
    """
    Allowed principal ids for auth. Required if `access_mode` is `required` or `restricted`. Ex: `azuread_user://<USER_ID>`  `azuread_group://<GROUP_ID>` (list)
    """
    annotations: pulumi.Output[dict]
    """
    Annotations of the resource (map)
    """
    application_id: pulumi.Output[str]
    """
    AzureAD auth application ID (string)
    """
    application_secret: pulumi.Output[str]
    """
    AzureAD auth application secret (string)
    """
    auth_endpoint: pulumi.Output[str]
    """
    AzureAD auth endpoint (string)
    """
    enabled: pulumi.Output[bool]
    """
    Enable auth config provider. Default `true` (bool)
    """
    endpoint: pulumi.Output[str]
    """
    AzureAD endpoint. Default `https://login.microsoftonline.com/` (string)
    """
    graph_endpoint: pulumi.Output[str]
    """
    AzureAD graph endpoint (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels of the resource (map)
    """
    name: pulumi.Output[str]
    """
    (Computed) The name of the resource (string)
    """
    rancher_url: pulumi.Output[str]
    """
    Rancher URL (string). "<rancher_url>/verify-auth-azure"
    """
    tenant_id: pulumi.Output[str]
    """
    AzureAD tenant ID (string)
    """
    token_endpoint: pulumi.Output[str]
    """
    AzureAD token endpoint (string)
    """
    type: pulumi.Output[str]
    """
    (Computed) The type of the resource (string)
    """
    def __init__(__self__, resource_name, opts=None, access_mode=None, allowed_principal_ids=None, annotations=None, application_id=None, application_secret=None, auth_endpoint=None, enabled=None, endpoint=None, graph_endpoint=None, labels=None, rancher_url=None, tenant_id=None, token_endpoint=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Auth Config AzureAD resource. This can be used to configure and enable Auth Config AzureAD for Rancher v2 RKE clusters and retrieve their information.

        In addition to the built-in local auth, only one external auth config provider can be enabled at a time.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_mode: Access mode for auth. `required`, `restricted`, `unrestricted` are supported. Default `unrestricted` (string)
        :param pulumi.Input[list] allowed_principal_ids: Allowed principal ids for auth. Required if `access_mode` is `required` or `restricted`. Ex: `azuread_user://<USER_ID>`  `azuread_group://<GROUP_ID>` (list)
        :param pulumi.Input[dict] annotations: Annotations of the resource (map)
        :param pulumi.Input[str] application_id: AzureAD auth application ID (string)
        :param pulumi.Input[str] application_secret: AzureAD auth application secret (string)
        :param pulumi.Input[str] auth_endpoint: AzureAD auth endpoint (string)
        :param pulumi.Input[bool] enabled: Enable auth config provider. Default `true` (bool)
        :param pulumi.Input[str] endpoint: AzureAD endpoint. Default `https://login.microsoftonline.com/` (string)
        :param pulumi.Input[str] graph_endpoint: AzureAD graph endpoint (string)
        :param pulumi.Input[dict] labels: Labels of the resource (map)
        :param pulumi.Input[str] rancher_url: Rancher URL (string). "<rancher_url>/verify-auth-azure"
        :param pulumi.Input[str] tenant_id: AzureAD tenant ID (string)
        :param pulumi.Input[str] token_endpoint: AzureAD token endpoint (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['access_mode'] = access_mode
            __props__['allowed_principal_ids'] = allowed_principal_ids
            __props__['annotations'] = annotations
            if application_id is None:
                raise TypeError("Missing required property 'application_id'")
            __props__['application_id'] = application_id
            if application_secret is None:
                raise TypeError("Missing required property 'application_secret'")
            __props__['application_secret'] = application_secret
            if auth_endpoint is None:
                raise TypeError("Missing required property 'auth_endpoint'")
            __props__['auth_endpoint'] = auth_endpoint
            __props__['enabled'] = enabled
            __props__['endpoint'] = endpoint
            if graph_endpoint is None:
                raise TypeError("Missing required property 'graph_endpoint'")
            __props__['graph_endpoint'] = graph_endpoint
            __props__['labels'] = labels
            if rancher_url is None:
                raise TypeError("Missing required property 'rancher_url'")
            __props__['rancher_url'] = rancher_url
            if tenant_id is None:
                raise TypeError("Missing required property 'tenant_id'")
            __props__['tenant_id'] = tenant_id
            if token_endpoint is None:
                raise TypeError("Missing required property 'token_endpoint'")
            __props__['token_endpoint'] = token_endpoint
            __props__['name'] = None
            __props__['type'] = None
        super(AuthConfigAzureAd, __self__).__init__(
            'rancher2:index/authConfigAzureAd:AuthConfigAzureAd',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, access_mode=None, allowed_principal_ids=None, annotations=None, application_id=None, application_secret=None, auth_endpoint=None, enabled=None, endpoint=None, graph_endpoint=None, labels=None, name=None, rancher_url=None, tenant_id=None, token_endpoint=None, type=None):
        """
        Get an existing AuthConfigAzureAd resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_mode: Access mode for auth. `required`, `restricted`, `unrestricted` are supported. Default `unrestricted` (string)
        :param pulumi.Input[list] allowed_principal_ids: Allowed principal ids for auth. Required if `access_mode` is `required` or `restricted`. Ex: `azuread_user://<USER_ID>`  `azuread_group://<GROUP_ID>` (list)
        :param pulumi.Input[dict] annotations: Annotations of the resource (map)
        :param pulumi.Input[str] application_id: AzureAD auth application ID (string)
        :param pulumi.Input[str] application_secret: AzureAD auth application secret (string)
        :param pulumi.Input[str] auth_endpoint: AzureAD auth endpoint (string)
        :param pulumi.Input[bool] enabled: Enable auth config provider. Default `true` (bool)
        :param pulumi.Input[str] endpoint: AzureAD endpoint. Default `https://login.microsoftonline.com/` (string)
        :param pulumi.Input[str] graph_endpoint: AzureAD graph endpoint (string)
        :param pulumi.Input[dict] labels: Labels of the resource (map)
        :param pulumi.Input[str] name: (Computed) The name of the resource (string)
        :param pulumi.Input[str] rancher_url: Rancher URL (string). "<rancher_url>/verify-auth-azure"
        :param pulumi.Input[str] tenant_id: AzureAD tenant ID (string)
        :param pulumi.Input[str] token_endpoint: AzureAD token endpoint (string)
        :param pulumi.Input[str] type: (Computed) The type of the resource (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["access_mode"] = access_mode
        __props__["allowed_principal_ids"] = allowed_principal_ids
        __props__["annotations"] = annotations
        __props__["application_id"] = application_id
        __props__["application_secret"] = application_secret
        __props__["auth_endpoint"] = auth_endpoint
        __props__["enabled"] = enabled
        __props__["endpoint"] = endpoint
        __props__["graph_endpoint"] = graph_endpoint
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["rancher_url"] = rancher_url
        __props__["tenant_id"] = tenant_id
        __props__["token_endpoint"] = token_endpoint
        __props__["type"] = type
        return AuthConfigAzureAd(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class Notifier(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for notifier object (map)
    """
    cluster_id: pulumi.Output[str]
    """
    The cluster id where create notifier (string)
    """
    description: pulumi.Output[str]
    """
    The notifier description (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for notifier object (map)
    """
    name: pulumi.Output[str]
    """
    The name of the notifier (string)
    """
    pagerduty_config: pulumi.Output[dict]
    """
    Pagerduty config for notifier (list maxitems:1)

      * `proxyUrl` (`str`) - Wechat proxy url (string)
      * `serviceKey` (`str`) - Pagerduty service key (string)
    """
    send_resolved: pulumi.Output[bool]
    """
    = (Optional) Enable the notifier to send resolved notifications. Default `false` (bool)
    """
    slack_config: pulumi.Output[dict]
    """
    Slack config for notifier (list maxitems:1)

      * `defaultRecipient` (`str`) - Wechat default recipient (string)
      * `proxyUrl` (`str`) - Wechat proxy url (string)
      * `url` (`str`) - Webhook url (string)
    """
    smtp_config: pulumi.Output[dict]
    """
    SMTP config for notifier (list maxitems:1)

      * `defaultRecipient` (`str`) - Wechat default recipient (string)
      * `host` (`str`) - SMTP host (string)
      * `password` (`str`) - SMTP password (string)
      * `port` (`float`) - SMTP port (int)
      * `sender` (`str`) - SMTP sender (string)
      * `tls` (`bool`) - SMTP tls. Default `true` (bool)
      * `username` (`str`) - SMTP username (string)
    """
    webhook_config: pulumi.Output[dict]
    """
    Webhook config for notifier (list maxitems:1)

      * `proxyUrl` (`str`) - Wechat proxy url (string)
      * `url` (`str`) - Webhook url (string)
    """
    wechat_config: pulumi.Output[dict]
    """
    Wechat config for notifier (list maxitems:1)

      * `agent` (`str`) - Wechat agent ID (string)
      * `corp` (`str`) - Wechat corporation ID (string)
      * `defaultRecipient` (`str`) - Wechat default recipient (string)
      * `proxyUrl` (`str`) - Wechat proxy url (string)
      * `recipientType` (`str`) - Wechat recipient type. Allowed values: `party` | `tag` | `user` (string)
      * `secret` (`str`) - Wechat agent ID (string)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, cluster_id=None, description=None, labels=None, name=None, pagerduty_config=None, send_resolved=None, slack_config=None, smtp_config=None, webhook_config=None, wechat_config=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Notifier resource. This can be used to create notifiers for Rancher v2 environments and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for notifier object (map)
        :param pulumi.Input[str] cluster_id: The cluster id where create notifier (string)
        :param pulumi.Input[str] description: The notifier description (string)
        :param pulumi.Input[dict] labels: Labels for notifier object (map)
        :param pulumi.Input[str] name: The name of the notifier (string)
        :param pulumi.Input[dict] pagerduty_config: Pagerduty config for notifier (list maxitems:1)
        :param pulumi.Input[bool] send_resolved: = (Optional) Enable the notifier to send resolved notifications. Default `false` (bool)
        :param pulumi.Input[dict] slack_config: Slack config for notifier (list maxitems:1)
        :param pulumi.Input[dict] smtp_config: SMTP config for notifier (list maxitems:1)
        :param pulumi.Input[dict] webhook_config: Webhook config for notifier (list maxitems:1)
        :param pulumi.Input[dict] wechat_config: Wechat config for notifier (list maxitems:1)

        The **pagerduty_config** object supports the following:

          * `proxyUrl` (`pulumi.Input[str]`) - Wechat proxy url (string)
          * `serviceKey` (`pulumi.Input[str]`) - Pagerduty service key (string)

        The **slack_config** object supports the following:

          * `defaultRecipient` (`pulumi.Input[str]`) - Wechat default recipient (string)
          * `proxyUrl` (`pulumi.Input[str]`) - Wechat proxy url (string)
          * `url` (`pulumi.Input[str]`) - Webhook url (string)

        The **smtp_config** object supports the following:

          * `defaultRecipient` (`pulumi.Input[str]`) - Wechat default recipient (string)
          * `host` (`pulumi.Input[str]`) - SMTP host (string)
          * `password` (`pulumi.Input[str]`) - SMTP password (string)
          * `port` (`pulumi.Input[float]`) - SMTP port (int)
          * `sender` (`pulumi.Input[str]`) - SMTP sender (string)
          * `tls` (`pulumi.Input[bool]`) - SMTP tls. Default `true` (bool)
          * `username` (`pulumi.Input[str]`) - SMTP username (string)

        The **webhook_config** object supports the following:

          * `proxyUrl` (`pulumi.Input[str]`) - Wechat proxy url (string)
          * `url` (`pulumi.Input[str]`) - Webhook url (string)

        The **wechat_config** object supports the following:

          * `agent` (`pulumi.Input[str]`) - Wechat agent ID (string)
          * `corp` (`pulumi.Input[str]`) - Wechat corporation ID (string)
          * `defaultRecipient` (`pulumi.Input[str]`) - Wechat default recipient (string)
          * `proxyUrl` (`pulumi.Input[str]`) - Wechat proxy url (string)
          * `recipientType` (`pulumi.Input[str]`) - Wechat recipient type. Allowed values: `party` | `tag` | `user` (string)
          * `secret` (`pulumi.Input[str]`) - Wechat agent ID (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            if cluster_id is None:
                raise TypeError("Missing required property 'cluster_id'")
            __props__['cluster_id'] = cluster_id
            __props__['description'] = description
            __props__['labels'] = labels
            __props__['name'] = name
            __props__['pagerduty_config'] = pagerduty_config
            __props__['send_resolved'] = send_resolved
            __props__['slack_config'] = slack_config
            __props__['smtp_config'] = smtp_config
            __props__['webhook_config'] = webhook_config
            __props__['wechat_config'] = wechat_config
        super(Notifier, __self__).__init__(
            'rancher2:index/notifier:Notifier',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, cluster_id=None, description=None, labels=None, name=None, pagerduty_config=None, send_resolved=None, slack_config=None, smtp_config=None, webhook_config=None, wechat_config=None):
        """
        Get an existing Notifier resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for notifier object (map)
        :param pulumi.Input[str] cluster_id: The cluster id where create notifier (string)
        :param pulumi.Input[str] description: The notifier description (string)
        :param pulumi.Input[dict] labels: Labels for notifier object (map)
        :param pulumi.Input[str] name: The name of the notifier (string)
        :param pulumi.Input[dict] pagerduty_config: Pagerduty config for notifier (list maxitems:1)
        :param pulumi.Input[bool] send_resolved: = (Optional) Enable the notifier to send resolved notifications. Default `false` (bool)
        :param pulumi.Input[dict] slack_config: Slack config for notifier (list maxitems:1)
        :param pulumi.Input[dict] smtp_config: SMTP config for notifier (list maxitems:1)
        :param pulumi.Input[dict] webhook_config: Webhook config for notifier (list maxitems:1)
        :param pulumi.Input[dict] wechat_config: Wechat config for notifier (list maxitems:1)

        The **pagerduty_config** object supports the following:

          * `proxyUrl` (`pulumi.Input[str]`) - Wechat proxy url (string)
          * `serviceKey` (`pulumi.Input[str]`) - Pagerduty service key (string)

        The **slack_config** object supports the following:

          * `defaultRecipient` (`pulumi.Input[str]`) - Wechat default recipient (string)
          * `proxyUrl` (`pulumi.Input[str]`) - Wechat proxy url (string)
          * `url` (`pulumi.Input[str]`) - Webhook url (string)

        The **smtp_config** object supports the following:

          * `defaultRecipient` (`pulumi.Input[str]`) - Wechat default recipient (string)
          * `host` (`pulumi.Input[str]`) - SMTP host (string)
          * `password` (`pulumi.Input[str]`) - SMTP password (string)
          * `port` (`pulumi.Input[float]`) - SMTP port (int)
          * `sender` (`pulumi.Input[str]`) - SMTP sender (string)
          * `tls` (`pulumi.Input[bool]`) - SMTP tls. Default `true` (bool)
          * `username` (`pulumi.Input[str]`) - SMTP username (string)

        The **webhook_config** object supports the following:

          * `proxyUrl` (`pulumi.Input[str]`) - Wechat proxy url (string)
          * `url` (`pulumi.Input[str]`) - Webhook url (string)

        The **wechat_config** object supports the following:

          * `agent` (`pulumi.Input[str]`) - Wechat agent ID (string)
          * `corp` (`pulumi.Input[str]`) - Wechat corporation ID (string)
          * `defaultRecipient` (`pulumi.Input[str]`) - Wechat default recipient (string)
          * `proxyUrl` (`pulumi.Input[str]`) - Wechat proxy url (string)
          * `recipientType` (`pulumi.Input[str]`) - Wechat recipient type. Allowed values: `party` | `tag` | `user` (string)
          * `secret` (`pulumi.Input[str]`) - Wechat agent ID (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["cluster_id"] = cluster_id
        __props__["description"] = description
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["pagerduty_config"] = pagerduty_config
        __props__["send_resolved"] = send_resolved
        __props__["slack_config"] = slack_config
        __props__["smtp_config"] = smtp_config
        __props__["webhook_config"] = webhook_config
        __props__["wechat_config"] = wechat_config
        return Notifier(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class ClusterDriver(pulumi.CustomResource):
    active: pulumi.Output[bool]
    """
    Specify the cluster driver state (bool)
    """
    actual_url: pulumi.Output[str]
    """
    Actual url of the cluster driver (string)
    """
    annotations: pulumi.Output[dict]
    """
    Annotations of the resource (map)
    """
    builtin: pulumi.Output[bool]
    """
    Specify whether the cluster driver is an internal cluster driver or not (bool)
    """
    checksum: pulumi.Output[str]
    """
    Verify that the downloaded driver matches the expected checksum (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels of the resource (map)
    """
    name: pulumi.Output[str]
    """
    Name of the cluster driver (string)
    """
    ui_url: pulumi.Output[str]
    """
    The URL to load for customized Add Clusters screen for this driver (string)
    """
    url: pulumi.Output[str]
    """
    The URL to download the machine driver binary for 64-bit Linux (string)
    """
    whitelist_domains: pulumi.Output[list]
    """
    Domains to whitelist for the ui (list)
    """
    def __init__(__self__, resource_name, opts=None, active=None, actual_url=None, annotations=None, builtin=None, checksum=None, labels=None, name=None, ui_url=None, url=None, whitelist_domains=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Cluster Driver resource. This can be used to create Cluster Driver for Rancher v2.2.x Kontainer Engine clusters and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Specify the cluster driver state (bool)
        :param pulumi.Input[str] actual_url: Actual url of the cluster driver (string)
        :param pulumi.Input[dict] annotations: Annotations of the resource (map)
        :param pulumi.Input[bool] builtin: Specify whether the cluster driver is an internal cluster driver or not (bool)
        :param pulumi.Input[str] checksum: Verify that the downloaded driver matches the expected checksum (string)
        :param pulumi.Input[dict] labels: Labels of the resource (map)
        :param pulumi.Input[str] name: Name of the cluster driver (string)
        :param pulumi.Input[str] ui_url: The URL to load for customized Add Clusters screen for this driver (string)
        :param pulumi.Input[str] url: The URL to download the machine driver binary for 64-bit Linux (string)
        :param pulumi.Input[list] whitelist_domains: Domains to whitelist for the ui (list)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if active is None:
                raise TypeError("Missing required property 'active'")
            __props__['active'] = active
            __props__['actual_url'] = actual_url
            __props__['annotations'] = annotations
            if builtin is None:
                raise TypeError("Missing required property 'builtin'")
            __props__['builtin'] = builtin
            __props__['checksum'] = checksum
            __props__['labels'] = labels
            __props__['name'] = name
            __props__['ui_url'] = ui_url
            if url is None:
                raise TypeError("Missing required property 'url'")
            __props__['url'] = url
            __props__['whitelist_domains'] = whitelist_domains
        super(ClusterDriver, __self__).__init__(
            'rancher2:index/clusterDriver:ClusterDriver',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, active=None, actual_url=None, annotations=None, builtin=None, checksum=None, labels=None, name=None, ui_url=None, url=None, whitelist_domains=None):
        """
        Get an existing ClusterDriver resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Specify the cluster driver state (bool)
        :param pulumi.Input[str] actual_url: Actual url of the cluster driver (string)
        :param pulumi.Input[dict] annotations: Annotations of the resource (map)
        :param pulumi.Input[bool] builtin: Specify whether the cluster driver is an internal cluster driver or not (bool)
        :param pulumi.Input[str] checksum: Verify that the downloaded driver matches the expected checksum (string)
        :param pulumi.Input[dict] labels: Labels of the resource (map)
        :param pulumi.Input[str] name: Name of the cluster driver (string)
        :param pulumi.Input[str] ui_url: The URL to load for customized Add Clusters screen for this driver (string)
        :param pulumi.Input[str] url: The URL to download the machine driver binary for 64-bit Linux (string)
        :param pulumi.Input[list] whitelist_domains: Domains to whitelist for the ui (list)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["active"] = active
        __props__["actual_url"] = actual_url
        __props__["annotations"] = annotations
        __props__["builtin"] = builtin
        __props__["checksum"] = checksum
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["ui_url"] = ui_url
        __props__["url"] = url
        __props__["whitelist_domains"] = whitelist_domains
        return ClusterDriver(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetProjectLoggingResult:
    """
    A collection of values returned by getProjectLogging.
    """
    def __init__(__self__, annotations=None, custom_target_config=None, elasticsearch_config=None, enable_json_parsing=None, fluentd_config=None, id=None, kafka_config=None, kind=None, labels=None, name=None, namespace_id=None, output_flush_interval=None, output_tags=None, project_id=None, splunk_config=None, syslog_config=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for Cluster Logging object (map)
        """
        if custom_target_config and not isinstance(custom_target_config, dict):
            raise TypeError("Expected argument 'custom_target_config' to be a dict")
        __self__.custom_target_config = custom_target_config
        if elasticsearch_config and not isinstance(elasticsearch_config, dict):
            raise TypeError("Expected argument 'elasticsearch_config' to be a dict")
        __self__.elasticsearch_config = elasticsearch_config
        """
        (Computed) The elasticsearch config for Cluster Logging. For `kind = elasticsearch`  (list maxitems:1)
        """
        if enable_json_parsing and not isinstance(enable_json_parsing, bool):
            raise TypeError("Expected argument 'enable_json_parsing' to be a bool")
        __self__.enable_json_parsing = enable_json_parsing
        if fluentd_config and not isinstance(fluentd_config, dict):
            raise TypeError("Expected argument 'fluentd_config' to be a dict")
        __self__.fluentd_config = fluentd_config
        """
        (Computed) The fluentd config for Cluster Logging. For `kind = fluentd` (list maxitems:1)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if kafka_config and not isinstance(kafka_config, dict):
            raise TypeError("Expected argument 'kafka_config' to be a dict")
        __self__.kafka_config = kafka_config
        """
        (Computed) The kafka config for Cluster Logging. For `kind = kafka` (list maxitems:1)
        """
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        __self__.kind = kind
        """
        (Computed) The kind of the Cluster Logging. `elasticsearch`, `fluentd`, `kafka`, `splunk` and `syslog` are supported (string)
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for Cluster Logging object (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        """
        (Computed) The name of the cluster logging config (string)
        """
        if namespace_id and not isinstance(namespace_id, str):
            raise TypeError("Expected argument 'namespace_id' to be a str")
        __self__.namespace_id = namespace_id
        """
        (Computed) The namespace id from cluster logging (string)
        """
        if output_flush_interval and not isinstance(output_flush_interval, float):
            raise TypeError("Expected argument 'output_flush_interval' to be a float")
        __self__.output_flush_interval = output_flush_interval
        """
        (Computed) How often buffered logs would be flushed. Default: `3` seconds (int)
        """
        if output_tags and not isinstance(output_tags, dict):
            raise TypeError("Expected argument 'output_tags' to be a dict")
        __self__.output_tags = output_tags
        """
        (computed) The output tags for Cluster Logging (map)
        """
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        __self__.project_id = project_id
        if splunk_config and not isinstance(splunk_config, dict):
            raise TypeError("Expected argument 'splunk_config' to be a dict")
        __self__.splunk_config = splunk_config
        """
        (Computed) The splunk config for Cluster Logging. For `kind = splunk` (list maxitems:1)
        """
        if syslog_config and not isinstance(syslog_config, dict):
            raise TypeError("Expected argument 'syslog_config' to be a dict")
        __self__.syslog_config = syslog_config
        """
        (Computed) The syslog config for Cluster Logging. For `kind = syslog` (list maxitems:1)
        """
class AwaitableGetProjectLoggingResult(GetProjectLoggingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectLoggingResult(
            annotations=self.annotations,
            custom_target_config=self.custom_target_config,
            elasticsearch_config=self.elasticsearch_config,
            enable_json_parsing=self.enable_json_parsing,
            fluentd_config=self.fluentd_config,
            id=self.id,
            kafka_config=self.kafka_config,
            kind=self.kind,
            labels=self.labels,
            name=self.name,
            namespace_id=self.namespace_id,
            output_flush_interval=self.output_flush_interval,
            output_tags=self.output_tags,
            project_id=self.project_id,
            splunk_config=self.splunk_config,
            syslog_config=self.syslog_config)

def get_project_logging(project_id=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 Project Logging.




    :param str project_id: The project id to configure logging (string)
    """
    __args__ = dict()


    __args__['projectId'] = project_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getProjectLogging:getProjectLogging', __args__, opts=opts).value

    return AwaitableGetProjectLoggingResult(
        annotations=__ret__.get('annotations'),
        custom_target_config=__ret__.get('customTargetConfig'),
        elasticsearch_config=__ret__.get('elasticsearchConfig'),
        enable_json_parsing=__ret__.get('enableJsonParsing'),
        fluentd_config=__ret__.get('fluentdConfig'),
        id=__ret__.get('id'),
        kafka_config=__ret__.get('kafkaConfig'),
        kind=__ret__.get('kind'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        namespace_id=__ret__.get('namespaceId'),
        output_flush_interval=__ret__.get('outputFlushInterval'),
        output_tags=__ret__.get('outputTags'),
        project_id=__ret__.get('projectId'),
        splunk_config=__ret__.get('splunkConfig'),
        syslog_config=__ret__.get('syslogConfig'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetRoleTemplateResult:
    """
    A collection of values returned by getRoleTemplate.
    """
    def __init__(__self__, administrative=None, annotations=None, builtin=None, context=None, default_role=None, description=None, external=None, hidden=None, id=None, labels=None, locked=None, name=None, role_template_ids=None, rules=None):
        if administrative and not isinstance(administrative, bool):
            raise TypeError("Expected argument 'administrative' to be a bool")
        __self__.administrative = administrative
        """
        (Computed) Administrative role template (bool)
        """
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for role template object (map)
        """
        if builtin and not isinstance(builtin, bool):
            raise TypeError("Expected argument 'builtin' to be a bool")
        __self__.builtin = builtin
        """
        (Computed) Builtin role template (string)
        """
        if context and not isinstance(context, str):
            raise TypeError("Expected argument 'context' to be a str")
        __self__.context = context
        if default_role and not isinstance(default_role, bool):
            raise TypeError("Expected argument 'default_role' to be a bool")
        __self__.default_role = default_role
        """
        (Computed) Default role template for new created cluster or project (bool)
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        (Computed) Role template description (string)
        """
        if external and not isinstance(external, bool):
            raise TypeError("Expected argument 'external' to be a bool")
        __self__.external = external
        """
        (Computed) External role template (bool)
        """
        if hidden and not isinstance(hidden, bool):
            raise TypeError("Expected argument 'hidden' to be a bool")
        __self__.hidden = hidden
        """
        (Computed) Hidden role template (bool)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for role template object (map)
        """
        if locked and not isinstance(locked, bool):
            raise TypeError("Expected argument 'locked' to be a bool")
        __self__.locked = locked
        """
        (Computed) Locked role template (bool)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if role_template_ids and not isinstance(role_template_ids, list):
            raise TypeError("Expected argument 'role_template_ids' to be a list")
        __self__.role_template_ids = role_template_ids
        """
        (Computed) Inherit role template IDs (list)
        """
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        __self__.rules = rules
        """
        (Computed) Role template policy rules (list)
        """
class AwaitableGetRoleTemplateResult(GetRoleTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRoleTemplateResult(
            administrative=self.administrative,
            annotations=self.annotations,
            builtin=self.builtin,
            context=self.context,
            default_role=self.default_role,
            description=self.description,
            external=self.external,
            hidden=self.hidden,
            id=self.id,
            labels=self.labels,
            locked=self.locked,
            name=self.name,
            role_template_ids=self.role_template_ids,
            rules=self.rules)

def get_role_template(context=None,name=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 role template resource.




    :param str context: Role template context. `cluster` and `project` values are supported (string)
    :param str name: The name of the Node Template (string)
    """
    __args__ = dict()


    __args__['context'] = context
    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getRoleTemplate:getRoleTemplate', __args__, opts=opts).value

    return AwaitableGetRoleTemplateResult(
        administrative=__ret__.get('administrative'),
        annotations=__ret__.get('annotations'),
        builtin=__ret__.get('builtin'),
        context=__ret__.get('context'),
        default_role=__ret__.get('defaultRole'),
        description=__ret__.get('description'),
        external=__ret__.get('external'),
        hidden=__ret__.get('hidden'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        locked=__ret__.get('locked'),
        name=__ret__.get('name'),
        role_template_ids=__ret__.get('roleTemplateIds'),
        rules=__ret__.get('rules'))
